# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ScalingGroupArgs', 'ScalingGroup']

@pulumi.input_type
class ScalingGroupArgs:
    def __init__(__self__, *,
                 max_instance_number: pulumi.Input[builtins.int],
                 min_instance_number: pulumi.Input[builtins.int],
                 scaling_group_name: pulumi.Input[builtins.str],
                 subnet_ids: pulumi.Input[Sequence[pulumi.Input[builtins.str]]],
                 active_scaling_configuration_id: Optional[pulumi.Input[builtins.str]] = None,
                 default_cooldown: Optional[pulumi.Input[builtins.int]] = None,
                 desire_instance_number: Optional[pulumi.Input[builtins.int]] = None,
                 health_check_type: Optional[pulumi.Input[builtins.str]] = None,
                 instance_terminate_policy: Optional[pulumi.Input[builtins.str]] = None,
                 instances_distribution: Optional[pulumi.Input['ScalingGroupInstancesDistributionArgs']] = None,
                 is_enable_scaling_group: Optional[pulumi.Input[builtins.bool]] = None,
                 launch_template_id: Optional[pulumi.Input[builtins.str]] = None,
                 launch_template_overrides: Optional[pulumi.Input[Sequence[pulumi.Input['ScalingGroupLaunchTemplateOverrideArgs']]]] = None,
                 launch_template_version: Optional[pulumi.Input[builtins.str]] = None,
                 multi_az_policy: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 scaling_mode: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_attributes: Optional[pulumi.Input[Sequence[pulumi.Input['ScalingGroupServerGroupAttributeArgs']]]] = None,
                 suspended_processes: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['ScalingGroupTagArgs']]]] = None):
        """
        The set of arguments for constructing a ScalingGroup resource.
        :param pulumi.Input[builtins.int] max_instance_number: 伸缩组中实例个数的最大值，默认取值0 ～ 100。您可以通过配额中心调整。
        :param pulumi.Input[builtins.int] min_instance_number: 伸缩组中实例个数的最小值，默认取值0 ～ 100。您可以通过配额中心调整。
        :param pulumi.Input[builtins.str] scaling_group_name: 伸缩组名称，同一地域下伸缩组名称唯一。只能以中文、字母开头，只能包含中文、字母、数字、下划线和中划线 。长度限制为1 ~ 128个字符。暂不支持特殊字符。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] subnet_ids: 伸缩组中实例主网卡的子网ID列表。
        :param pulumi.Input[builtins.str] active_scaling_configuration_id: 伸缩组绑定的伸缩配置的ID。
        :param pulumi.Input[builtins.int] default_cooldown: 执行一次伸缩活动（添加或移出ECS实例）结束后的冷却时间。冷却时间内，该伸缩组不执行其它的伸缩活动，仅针对云监控报警任务触发的伸缩活动和伸缩规则有效。取值范围：5 ~ 86400，单位：秒。默认值：300。
        :param pulumi.Input[builtins.int] desire_instance_number: 伸缩组中期望运行的实例个数。1、不小于最小实例数MinInstanceNumber且不大于最大实例数MaxInstanceNumber。2、默认值：-1，表示不开启期望实例数能力。此时，伸缩组创建完成后会立即开始伸缩活动自动添加相应个数的实例。
        :param pulumi.Input[builtins.str] health_check_type: 伸缩组的健康检查方式。1、NONE：不做实例健康状态检查。2、ECS（默认）：对伸缩组内的ECS实例做健康检查。
        :param pulumi.Input[builtins.str] instance_terminate_policy: 实例移除策略，1、OldestInstance：移出最早加入 （包括自动创建和手动添加）伸缩组的实例。2、NewestInstance：移出最晚加入（包括自动创建和手动添加）伸缩组的实例。3、OldestScalingConfigurationWithOldestInstance（默认）：移出最早与伸缩组绑定的伸缩配置中，最早由伸缩组 自动创建 的实例。4、OldestScalingConfigurationWithNewestInstance：移出最早与伸缩组绑定的伸缩配置中，最晚由伸缩组 自动创建 的实例。
        :param pulumi.Input['ScalingGroupInstancesDistributionArgs'] instances_distribution: 实例分布策略。
        :param pulumi.Input[builtins.bool] is_enable_scaling_group: 是否启用伸缩组。true：启用。false：停止
        :param pulumi.Input[builtins.str] launch_template_id: 实例启动模板ID，配置后表示选择启动模版作为伸缩配置来源。
        :param pulumi.Input[builtins.str] launch_template_version: 实例启动模板的版本。1、模板的某个版本号。2、Default（默认）：始终使用模板默认版本。3、Latest：始终使用模板最新版本。
        :param pulumi.Input[builtins.str] multi_az_policy: 扩缩容策略，如果您选择了多个子网，需配置本参数。1、PRIORITY（默认）：优先级策略。2、BALANCE：均衡分布策略。
        :param pulumi.Input[builtins.str] project_name: 伸缩组所属项目，默认为default。一个资源只能归属于一个项目。只能包含字母、数字、下划线“_”、点“.”和中划线“-”。长度限制在64个字符以内。
        :param pulumi.Input[builtins.str] scaling_mode: 伸缩组的实例回收模式。1、release（默认）：释放模式。2、recycle：停机回收模式。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] suspended_processes: 暂停中的流程，无暂停中流程则返回空值。ScaleIn：缩容流程。ScaleOut：扩容流程。HealthCheck：健康检查。AlarmNotification：报警任务。ScheduledAction：定时任务。
        """
        pulumi.set(__self__, "max_instance_number", max_instance_number)
        pulumi.set(__self__, "min_instance_number", min_instance_number)
        pulumi.set(__self__, "scaling_group_name", scaling_group_name)
        pulumi.set(__self__, "subnet_ids", subnet_ids)
        if active_scaling_configuration_id is not None:
            pulumi.set(__self__, "active_scaling_configuration_id", active_scaling_configuration_id)
        if default_cooldown is not None:
            pulumi.set(__self__, "default_cooldown", default_cooldown)
        if desire_instance_number is not None:
            pulumi.set(__self__, "desire_instance_number", desire_instance_number)
        if health_check_type is not None:
            pulumi.set(__self__, "health_check_type", health_check_type)
        if instance_terminate_policy is not None:
            pulumi.set(__self__, "instance_terminate_policy", instance_terminate_policy)
        if instances_distribution is not None:
            pulumi.set(__self__, "instances_distribution", instances_distribution)
        if is_enable_scaling_group is not None:
            pulumi.set(__self__, "is_enable_scaling_group", is_enable_scaling_group)
        if launch_template_id is not None:
            pulumi.set(__self__, "launch_template_id", launch_template_id)
        if launch_template_overrides is not None:
            pulumi.set(__self__, "launch_template_overrides", launch_template_overrides)
        if launch_template_version is not None:
            pulumi.set(__self__, "launch_template_version", launch_template_version)
        if multi_az_policy is not None:
            pulumi.set(__self__, "multi_az_policy", multi_az_policy)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if scaling_mode is not None:
            pulumi.set(__self__, "scaling_mode", scaling_mode)
        if server_group_attributes is not None:
            pulumi.set(__self__, "server_group_attributes", server_group_attributes)
        if suspended_processes is not None:
            pulumi.set(__self__, "suspended_processes", suspended_processes)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="maxInstanceNumber")
    def max_instance_number(self) -> pulumi.Input[builtins.int]:
        """
        伸缩组中实例个数的最大值，默认取值0 ～ 100。您可以通过配额中心调整。
        """
        return pulumi.get(self, "max_instance_number")

    @max_instance_number.setter
    def max_instance_number(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "max_instance_number", value)

    @property
    @pulumi.getter(name="minInstanceNumber")
    def min_instance_number(self) -> pulumi.Input[builtins.int]:
        """
        伸缩组中实例个数的最小值，默认取值0 ～ 100。您可以通过配额中心调整。
        """
        return pulumi.get(self, "min_instance_number")

    @min_instance_number.setter
    def min_instance_number(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "min_instance_number", value)

    @property
    @pulumi.getter(name="scalingGroupName")
    def scaling_group_name(self) -> pulumi.Input[builtins.str]:
        """
        伸缩组名称，同一地域下伸缩组名称唯一。只能以中文、字母开头，只能包含中文、字母、数字、下划线和中划线 。长度限制为1 ~ 128个字符。暂不支持特殊字符。
        """
        return pulumi.get(self, "scaling_group_name")

    @scaling_group_name.setter
    def scaling_group_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "scaling_group_name", value)

    @property
    @pulumi.getter(name="subnetIds")
    def subnet_ids(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        """
        伸缩组中实例主网卡的子网ID列表。
        """
        return pulumi.get(self, "subnet_ids")

    @subnet_ids.setter
    def subnet_ids(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "subnet_ids", value)

    @property
    @pulumi.getter(name="activeScalingConfigurationId")
    def active_scaling_configuration_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        伸缩组绑定的伸缩配置的ID。
        """
        return pulumi.get(self, "active_scaling_configuration_id")

    @active_scaling_configuration_id.setter
    def active_scaling_configuration_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "active_scaling_configuration_id", value)

    @property
    @pulumi.getter(name="defaultCooldown")
    def default_cooldown(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        执行一次伸缩活动（添加或移出ECS实例）结束后的冷却时间。冷却时间内，该伸缩组不执行其它的伸缩活动，仅针对云监控报警任务触发的伸缩活动和伸缩规则有效。取值范围：5 ~ 86400，单位：秒。默认值：300。
        """
        return pulumi.get(self, "default_cooldown")

    @default_cooldown.setter
    def default_cooldown(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "default_cooldown", value)

    @property
    @pulumi.getter(name="desireInstanceNumber")
    def desire_instance_number(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        伸缩组中期望运行的实例个数。1、不小于最小实例数MinInstanceNumber且不大于最大实例数MaxInstanceNumber。2、默认值：-1，表示不开启期望实例数能力。此时，伸缩组创建完成后会立即开始伸缩活动自动添加相应个数的实例。
        """
        return pulumi.get(self, "desire_instance_number")

    @desire_instance_number.setter
    def desire_instance_number(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "desire_instance_number", value)

    @property
    @pulumi.getter(name="healthCheckType")
    def health_check_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        伸缩组的健康检查方式。1、NONE：不做实例健康状态检查。2、ECS（默认）：对伸缩组内的ECS实例做健康检查。
        """
        return pulumi.get(self, "health_check_type")

    @health_check_type.setter
    def health_check_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "health_check_type", value)

    @property
    @pulumi.getter(name="instanceTerminatePolicy")
    def instance_terminate_policy(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例移除策略，1、OldestInstance：移出最早加入 （包括自动创建和手动添加）伸缩组的实例。2、NewestInstance：移出最晚加入（包括自动创建和手动添加）伸缩组的实例。3、OldestScalingConfigurationWithOldestInstance（默认）：移出最早与伸缩组绑定的伸缩配置中，最早由伸缩组 自动创建 的实例。4、OldestScalingConfigurationWithNewestInstance：移出最早与伸缩组绑定的伸缩配置中，最晚由伸缩组 自动创建 的实例。
        """
        return pulumi.get(self, "instance_terminate_policy")

    @instance_terminate_policy.setter
    def instance_terminate_policy(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_terminate_policy", value)

    @property
    @pulumi.getter(name="instancesDistribution")
    def instances_distribution(self) -> Optional[pulumi.Input['ScalingGroupInstancesDistributionArgs']]:
        """
        实例分布策略。
        """
        return pulumi.get(self, "instances_distribution")

    @instances_distribution.setter
    def instances_distribution(self, value: Optional[pulumi.Input['ScalingGroupInstancesDistributionArgs']]):
        pulumi.set(self, "instances_distribution", value)

    @property
    @pulumi.getter(name="isEnableScalingGroup")
    def is_enable_scaling_group(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否启用伸缩组。true：启用。false：停止
        """
        return pulumi.get(self, "is_enable_scaling_group")

    @is_enable_scaling_group.setter
    def is_enable_scaling_group(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_enable_scaling_group", value)

    @property
    @pulumi.getter(name="launchTemplateId")
    def launch_template_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例启动模板ID，配置后表示选择启动模版作为伸缩配置来源。
        """
        return pulumi.get(self, "launch_template_id")

    @launch_template_id.setter
    def launch_template_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "launch_template_id", value)

    @property
    @pulumi.getter(name="launchTemplateOverrides")
    def launch_template_overrides(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ScalingGroupLaunchTemplateOverrideArgs']]]]:
        return pulumi.get(self, "launch_template_overrides")

    @launch_template_overrides.setter
    def launch_template_overrides(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ScalingGroupLaunchTemplateOverrideArgs']]]]):
        pulumi.set(self, "launch_template_overrides", value)

    @property
    @pulumi.getter(name="launchTemplateVersion")
    def launch_template_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例启动模板的版本。1、模板的某个版本号。2、Default（默认）：始终使用模板默认版本。3、Latest：始终使用模板最新版本。
        """
        return pulumi.get(self, "launch_template_version")

    @launch_template_version.setter
    def launch_template_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "launch_template_version", value)

    @property
    @pulumi.getter(name="multiAzPolicy")
    def multi_az_policy(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        扩缩容策略，如果您选择了多个子网，需配置本参数。1、PRIORITY（默认）：优先级策略。2、BALANCE：均衡分布策略。
        """
        return pulumi.get(self, "multi_az_policy")

    @multi_az_policy.setter
    def multi_az_policy(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "multi_az_policy", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        伸缩组所属项目，默认为default。一个资源只能归属于一个项目。只能包含字母、数字、下划线“_”、点“.”和中划线“-”。长度限制在64个字符以内。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="scalingMode")
    def scaling_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        伸缩组的实例回收模式。1、release（默认）：释放模式。2、recycle：停机回收模式。
        """
        return pulumi.get(self, "scaling_mode")

    @scaling_mode.setter
    def scaling_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "scaling_mode", value)

    @property
    @pulumi.getter(name="serverGroupAttributes")
    def server_group_attributes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ScalingGroupServerGroupAttributeArgs']]]]:
        return pulumi.get(self, "server_group_attributes")

    @server_group_attributes.setter
    def server_group_attributes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ScalingGroupServerGroupAttributeArgs']]]]):
        pulumi.set(self, "server_group_attributes", value)

    @property
    @pulumi.getter(name="suspendedProcesses")
    def suspended_processes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        暂停中的流程，无暂停中流程则返回空值。ScaleIn：缩容流程。ScaleOut：扩容流程。HealthCheck：健康检查。AlarmNotification：报警任务。ScheduledAction：定时任务。
        """
        return pulumi.get(self, "suspended_processes")

    @suspended_processes.setter
    def suspended_processes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "suspended_processes", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ScalingGroupTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ScalingGroupTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ScalingGroupState:
    def __init__(__self__, *,
                 active_scaling_configuration_id: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 db_instance_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 default_cooldown: Optional[pulumi.Input[builtins.int]] = None,
                 desire_instance_number: Optional[pulumi.Input[builtins.int]] = None,
                 health_check_type: Optional[pulumi.Input[builtins.str]] = None,
                 instance_terminate_policy: Optional[pulumi.Input[builtins.str]] = None,
                 instances_distribution: Optional[pulumi.Input['ScalingGroupInstancesDistributionArgs']] = None,
                 is_enable_scaling_group: Optional[pulumi.Input[builtins.bool]] = None,
                 launch_template_id: Optional[pulumi.Input[builtins.str]] = None,
                 launch_template_overrides: Optional[pulumi.Input[Sequence[pulumi.Input['ScalingGroupLaunchTemplateOverrideArgs']]]] = None,
                 launch_template_version: Optional[pulumi.Input[builtins.str]] = None,
                 lifecycle_state: Optional[pulumi.Input[builtins.str]] = None,
                 load_balancer_health_check_grace_period: Optional[pulumi.Input[builtins.int]] = None,
                 max_instance_number: Optional[pulumi.Input[builtins.int]] = None,
                 min_instance_number: Optional[pulumi.Input[builtins.int]] = None,
                 multi_az_policy: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 scaling_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 scaling_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 scaling_mode: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_attributes: Optional[pulumi.Input[Sequence[pulumi.Input['ScalingGroupServerGroupAttributeArgs']]]] = None,
                 stopped_instance_count: Optional[pulumi.Input[builtins.int]] = None,
                 subnet_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 suspended_processes: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['ScalingGroupTagArgs']]]] = None,
                 total_instance_count: Optional[pulumi.Input[builtins.int]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering ScalingGroup resources.
        :param pulumi.Input[builtins.str] active_scaling_configuration_id: 伸缩组绑定的伸缩配置的ID。
        :param pulumi.Input[builtins.str] created_time: 伸缩组创建时间。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] db_instance_ids: RDS数据库实例的ID。
        :param pulumi.Input[builtins.int] default_cooldown: 执行一次伸缩活动（添加或移出ECS实例）结束后的冷却时间。冷却时间内，该伸缩组不执行其它的伸缩活动，仅针对云监控报警任务触发的伸缩活动和伸缩规则有效。取值范围：5 ~ 86400，单位：秒。默认值：300。
        :param pulumi.Input[builtins.int] desire_instance_number: 伸缩组中期望运行的实例个数。1、不小于最小实例数MinInstanceNumber且不大于最大实例数MaxInstanceNumber。2、默认值：-1，表示不开启期望实例数能力。此时，伸缩组创建完成后会立即开始伸缩活动自动添加相应个数的实例。
        :param pulumi.Input[builtins.str] health_check_type: 伸缩组的健康检查方式。1、NONE：不做实例健康状态检查。2、ECS（默认）：对伸缩组内的ECS实例做健康检查。
        :param pulumi.Input[builtins.str] instance_terminate_policy: 实例移除策略，1、OldestInstance：移出最早加入 （包括自动创建和手动添加）伸缩组的实例。2、NewestInstance：移出最晚加入（包括自动创建和手动添加）伸缩组的实例。3、OldestScalingConfigurationWithOldestInstance（默认）：移出最早与伸缩组绑定的伸缩配置中，最早由伸缩组 自动创建 的实例。4、OldestScalingConfigurationWithNewestInstance：移出最早与伸缩组绑定的伸缩配置中，最晚由伸缩组 自动创建 的实例。
        :param pulumi.Input['ScalingGroupInstancesDistributionArgs'] instances_distribution: 实例分布策略。
        :param pulumi.Input[builtins.bool] is_enable_scaling_group: 是否启用伸缩组。true：启用。false：停止
        :param pulumi.Input[builtins.str] launch_template_id: 实例启动模板ID，配置后表示选择启动模版作为伸缩配置来源。
        :param pulumi.Input[builtins.str] launch_template_version: 实例启动模板的版本。1、模板的某个版本号。2、Default（默认）：始终使用模板默认版本。3、Latest：始终使用模板最新版本。
        :param pulumi.Input[builtins.str] lifecycle_state: 伸缩组的状态。Active：已启用。InActive：未激活。Deleting：删除中。Locked: 已锁定。CoolingDown: 冷却中。Unknown: 未知状态。
        :param pulumi.Input[builtins.int] load_balancer_health_check_grace_period: 伸缩组实例CLB健康状况检查宽限期。
        :param pulumi.Input[builtins.int] max_instance_number: 伸缩组中实例个数的最大值，默认取值0 ～ 100。您可以通过配额中心调整。
        :param pulumi.Input[builtins.int] min_instance_number: 伸缩组中实例个数的最小值，默认取值0 ～ 100。您可以通过配额中心调整。
        :param pulumi.Input[builtins.str] multi_az_policy: 扩缩容策略，如果您选择了多个子网，需配置本参数。1、PRIORITY（默认）：优先级策略。2、BALANCE：均衡分布策略。
        :param pulumi.Input[builtins.str] project_name: 伸缩组所属项目，默认为default。一个资源只能归属于一个项目。只能包含字母、数字、下划线“_”、点“.”和中划线“-”。长度限制在64个字符以内。
        :param pulumi.Input[builtins.str] scaling_group_id: 伸缩组ID。
        :param pulumi.Input[builtins.str] scaling_group_name: 伸缩组名称，同一地域下伸缩组名称唯一。只能以中文、字母开头，只能包含中文、字母、数字、下划线和中划线 。长度限制为1 ~ 128个字符。暂不支持特殊字符。
        :param pulumi.Input[builtins.str] scaling_mode: 伸缩组的实例回收模式。1、release（默认）：释放模式。2、recycle：停机回收模式。
        :param pulumi.Input[builtins.int] stopped_instance_count: 伸缩组内处于停用中状态的实例数量。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] subnet_ids: 伸缩组中实例主网卡的子网ID列表。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] suspended_processes: 暂停中的流程，无暂停中流程则返回空值。ScaleIn：缩容流程。ScaleOut：扩容流程。HealthCheck：健康检查。AlarmNotification：报警任务。ScheduledAction：定时任务。
        :param pulumi.Input[builtins.int] total_instance_count: 当前伸缩组内实例的个数。
        :param pulumi.Input[builtins.str] updated_time: 伸缩组更新时间。
        :param pulumi.Input[builtins.str] vpc_id: 伸缩组所属私有网络ID。
        """
        if active_scaling_configuration_id is not None:
            pulumi.set(__self__, "active_scaling_configuration_id", active_scaling_configuration_id)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if db_instance_ids is not None:
            pulumi.set(__self__, "db_instance_ids", db_instance_ids)
        if default_cooldown is not None:
            pulumi.set(__self__, "default_cooldown", default_cooldown)
        if desire_instance_number is not None:
            pulumi.set(__self__, "desire_instance_number", desire_instance_number)
        if health_check_type is not None:
            pulumi.set(__self__, "health_check_type", health_check_type)
        if instance_terminate_policy is not None:
            pulumi.set(__self__, "instance_terminate_policy", instance_terminate_policy)
        if instances_distribution is not None:
            pulumi.set(__self__, "instances_distribution", instances_distribution)
        if is_enable_scaling_group is not None:
            pulumi.set(__self__, "is_enable_scaling_group", is_enable_scaling_group)
        if launch_template_id is not None:
            pulumi.set(__self__, "launch_template_id", launch_template_id)
        if launch_template_overrides is not None:
            pulumi.set(__self__, "launch_template_overrides", launch_template_overrides)
        if launch_template_version is not None:
            pulumi.set(__self__, "launch_template_version", launch_template_version)
        if lifecycle_state is not None:
            pulumi.set(__self__, "lifecycle_state", lifecycle_state)
        if load_balancer_health_check_grace_period is not None:
            pulumi.set(__self__, "load_balancer_health_check_grace_period", load_balancer_health_check_grace_period)
        if max_instance_number is not None:
            pulumi.set(__self__, "max_instance_number", max_instance_number)
        if min_instance_number is not None:
            pulumi.set(__self__, "min_instance_number", min_instance_number)
        if multi_az_policy is not None:
            pulumi.set(__self__, "multi_az_policy", multi_az_policy)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if scaling_group_id is not None:
            pulumi.set(__self__, "scaling_group_id", scaling_group_id)
        if scaling_group_name is not None:
            pulumi.set(__self__, "scaling_group_name", scaling_group_name)
        if scaling_mode is not None:
            pulumi.set(__self__, "scaling_mode", scaling_mode)
        if server_group_attributes is not None:
            pulumi.set(__self__, "server_group_attributes", server_group_attributes)
        if stopped_instance_count is not None:
            pulumi.set(__self__, "stopped_instance_count", stopped_instance_count)
        if subnet_ids is not None:
            pulumi.set(__self__, "subnet_ids", subnet_ids)
        if suspended_processes is not None:
            pulumi.set(__self__, "suspended_processes", suspended_processes)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if total_instance_count is not None:
            pulumi.set(__self__, "total_instance_count", total_instance_count)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="activeScalingConfigurationId")
    def active_scaling_configuration_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        伸缩组绑定的伸缩配置的ID。
        """
        return pulumi.get(self, "active_scaling_configuration_id")

    @active_scaling_configuration_id.setter
    def active_scaling_configuration_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "active_scaling_configuration_id", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        伸缩组创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="dbInstanceIds")
    def db_instance_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        RDS数据库实例的ID。
        """
        return pulumi.get(self, "db_instance_ids")

    @db_instance_ids.setter
    def db_instance_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "db_instance_ids", value)

    @property
    @pulumi.getter(name="defaultCooldown")
    def default_cooldown(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        执行一次伸缩活动（添加或移出ECS实例）结束后的冷却时间。冷却时间内，该伸缩组不执行其它的伸缩活动，仅针对云监控报警任务触发的伸缩活动和伸缩规则有效。取值范围：5 ~ 86400，单位：秒。默认值：300。
        """
        return pulumi.get(self, "default_cooldown")

    @default_cooldown.setter
    def default_cooldown(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "default_cooldown", value)

    @property
    @pulumi.getter(name="desireInstanceNumber")
    def desire_instance_number(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        伸缩组中期望运行的实例个数。1、不小于最小实例数MinInstanceNumber且不大于最大实例数MaxInstanceNumber。2、默认值：-1，表示不开启期望实例数能力。此时，伸缩组创建完成后会立即开始伸缩活动自动添加相应个数的实例。
        """
        return pulumi.get(self, "desire_instance_number")

    @desire_instance_number.setter
    def desire_instance_number(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "desire_instance_number", value)

    @property
    @pulumi.getter(name="healthCheckType")
    def health_check_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        伸缩组的健康检查方式。1、NONE：不做实例健康状态检查。2、ECS（默认）：对伸缩组内的ECS实例做健康检查。
        """
        return pulumi.get(self, "health_check_type")

    @health_check_type.setter
    def health_check_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "health_check_type", value)

    @property
    @pulumi.getter(name="instanceTerminatePolicy")
    def instance_terminate_policy(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例移除策略，1、OldestInstance：移出最早加入 （包括自动创建和手动添加）伸缩组的实例。2、NewestInstance：移出最晚加入（包括自动创建和手动添加）伸缩组的实例。3、OldestScalingConfigurationWithOldestInstance（默认）：移出最早与伸缩组绑定的伸缩配置中，最早由伸缩组 自动创建 的实例。4、OldestScalingConfigurationWithNewestInstance：移出最早与伸缩组绑定的伸缩配置中，最晚由伸缩组 自动创建 的实例。
        """
        return pulumi.get(self, "instance_terminate_policy")

    @instance_terminate_policy.setter
    def instance_terminate_policy(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_terminate_policy", value)

    @property
    @pulumi.getter(name="instancesDistribution")
    def instances_distribution(self) -> Optional[pulumi.Input['ScalingGroupInstancesDistributionArgs']]:
        """
        实例分布策略。
        """
        return pulumi.get(self, "instances_distribution")

    @instances_distribution.setter
    def instances_distribution(self, value: Optional[pulumi.Input['ScalingGroupInstancesDistributionArgs']]):
        pulumi.set(self, "instances_distribution", value)

    @property
    @pulumi.getter(name="isEnableScalingGroup")
    def is_enable_scaling_group(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否启用伸缩组。true：启用。false：停止
        """
        return pulumi.get(self, "is_enable_scaling_group")

    @is_enable_scaling_group.setter
    def is_enable_scaling_group(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_enable_scaling_group", value)

    @property
    @pulumi.getter(name="launchTemplateId")
    def launch_template_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例启动模板ID，配置后表示选择启动模版作为伸缩配置来源。
        """
        return pulumi.get(self, "launch_template_id")

    @launch_template_id.setter
    def launch_template_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "launch_template_id", value)

    @property
    @pulumi.getter(name="launchTemplateOverrides")
    def launch_template_overrides(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ScalingGroupLaunchTemplateOverrideArgs']]]]:
        return pulumi.get(self, "launch_template_overrides")

    @launch_template_overrides.setter
    def launch_template_overrides(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ScalingGroupLaunchTemplateOverrideArgs']]]]):
        pulumi.set(self, "launch_template_overrides", value)

    @property
    @pulumi.getter(name="launchTemplateVersion")
    def launch_template_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例启动模板的版本。1、模板的某个版本号。2、Default（默认）：始终使用模板默认版本。3、Latest：始终使用模板最新版本。
        """
        return pulumi.get(self, "launch_template_version")

    @launch_template_version.setter
    def launch_template_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "launch_template_version", value)

    @property
    @pulumi.getter(name="lifecycleState")
    def lifecycle_state(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        伸缩组的状态。Active：已启用。InActive：未激活。Deleting：删除中。Locked: 已锁定。CoolingDown: 冷却中。Unknown: 未知状态。
        """
        return pulumi.get(self, "lifecycle_state")

    @lifecycle_state.setter
    def lifecycle_state(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "lifecycle_state", value)

    @property
    @pulumi.getter(name="loadBalancerHealthCheckGracePeriod")
    def load_balancer_health_check_grace_period(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        伸缩组实例CLB健康状况检查宽限期。
        """
        return pulumi.get(self, "load_balancer_health_check_grace_period")

    @load_balancer_health_check_grace_period.setter
    def load_balancer_health_check_grace_period(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "load_balancer_health_check_grace_period", value)

    @property
    @pulumi.getter(name="maxInstanceNumber")
    def max_instance_number(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        伸缩组中实例个数的最大值，默认取值0 ～ 100。您可以通过配额中心调整。
        """
        return pulumi.get(self, "max_instance_number")

    @max_instance_number.setter
    def max_instance_number(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "max_instance_number", value)

    @property
    @pulumi.getter(name="minInstanceNumber")
    def min_instance_number(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        伸缩组中实例个数的最小值，默认取值0 ～ 100。您可以通过配额中心调整。
        """
        return pulumi.get(self, "min_instance_number")

    @min_instance_number.setter
    def min_instance_number(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "min_instance_number", value)

    @property
    @pulumi.getter(name="multiAzPolicy")
    def multi_az_policy(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        扩缩容策略，如果您选择了多个子网，需配置本参数。1、PRIORITY（默认）：优先级策略。2、BALANCE：均衡分布策略。
        """
        return pulumi.get(self, "multi_az_policy")

    @multi_az_policy.setter
    def multi_az_policy(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "multi_az_policy", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        伸缩组所属项目，默认为default。一个资源只能归属于一个项目。只能包含字母、数字、下划线“_”、点“.”和中划线“-”。长度限制在64个字符以内。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="scalingGroupId")
    def scaling_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        伸缩组ID。
        """
        return pulumi.get(self, "scaling_group_id")

    @scaling_group_id.setter
    def scaling_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "scaling_group_id", value)

    @property
    @pulumi.getter(name="scalingGroupName")
    def scaling_group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        伸缩组名称，同一地域下伸缩组名称唯一。只能以中文、字母开头，只能包含中文、字母、数字、下划线和中划线 。长度限制为1 ~ 128个字符。暂不支持特殊字符。
        """
        return pulumi.get(self, "scaling_group_name")

    @scaling_group_name.setter
    def scaling_group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "scaling_group_name", value)

    @property
    @pulumi.getter(name="scalingMode")
    def scaling_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        伸缩组的实例回收模式。1、release（默认）：释放模式。2、recycle：停机回收模式。
        """
        return pulumi.get(self, "scaling_mode")

    @scaling_mode.setter
    def scaling_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "scaling_mode", value)

    @property
    @pulumi.getter(name="serverGroupAttributes")
    def server_group_attributes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ScalingGroupServerGroupAttributeArgs']]]]:
        return pulumi.get(self, "server_group_attributes")

    @server_group_attributes.setter
    def server_group_attributes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ScalingGroupServerGroupAttributeArgs']]]]):
        pulumi.set(self, "server_group_attributes", value)

    @property
    @pulumi.getter(name="stoppedInstanceCount")
    def stopped_instance_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        伸缩组内处于停用中状态的实例数量。
        """
        return pulumi.get(self, "stopped_instance_count")

    @stopped_instance_count.setter
    def stopped_instance_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "stopped_instance_count", value)

    @property
    @pulumi.getter(name="subnetIds")
    def subnet_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        伸缩组中实例主网卡的子网ID列表。
        """
        return pulumi.get(self, "subnet_ids")

    @subnet_ids.setter
    def subnet_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "subnet_ids", value)

    @property
    @pulumi.getter(name="suspendedProcesses")
    def suspended_processes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        暂停中的流程，无暂停中流程则返回空值。ScaleIn：缩容流程。ScaleOut：扩容流程。HealthCheck：健康检查。AlarmNotification：报警任务。ScheduledAction：定时任务。
        """
        return pulumi.get(self, "suspended_processes")

    @suspended_processes.setter
    def suspended_processes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "suspended_processes", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ScalingGroupTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ScalingGroupTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="totalInstanceCount")
    def total_instance_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        当前伸缩组内实例的个数。
        """
        return pulumi.get(self, "total_instance_count")

    @total_instance_count.setter
    def total_instance_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "total_instance_count", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        伸缩组更新时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        伸缩组所属私有网络ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)


@pulumi.type_token("bytepluscc:autoscaling/scalingGroup:ScalingGroup")
class ScalingGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 active_scaling_configuration_id: Optional[pulumi.Input[builtins.str]] = None,
                 default_cooldown: Optional[pulumi.Input[builtins.int]] = None,
                 desire_instance_number: Optional[pulumi.Input[builtins.int]] = None,
                 health_check_type: Optional[pulumi.Input[builtins.str]] = None,
                 instance_terminate_policy: Optional[pulumi.Input[builtins.str]] = None,
                 instances_distribution: Optional[pulumi.Input[Union['ScalingGroupInstancesDistributionArgs', 'ScalingGroupInstancesDistributionArgsDict']]] = None,
                 is_enable_scaling_group: Optional[pulumi.Input[builtins.bool]] = None,
                 launch_template_id: Optional[pulumi.Input[builtins.str]] = None,
                 launch_template_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ScalingGroupLaunchTemplateOverrideArgs', 'ScalingGroupLaunchTemplateOverrideArgsDict']]]]] = None,
                 launch_template_version: Optional[pulumi.Input[builtins.str]] = None,
                 max_instance_number: Optional[pulumi.Input[builtins.int]] = None,
                 min_instance_number: Optional[pulumi.Input[builtins.int]] = None,
                 multi_az_policy: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 scaling_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 scaling_mode: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_attributes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ScalingGroupServerGroupAttributeArgs', 'ScalingGroupServerGroupAttributeArgsDict']]]]] = None,
                 subnet_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 suspended_processes: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ScalingGroupTagArgs', 'ScalingGroupTagArgsDict']]]]] = None,
                 __props__=None):
        """
        伸缩组用于管理一组云资源实例。通过伸缩组可以定义云资源池中的实例数/容量、冷却时间、负载均衡等信息。

        ## Import

        ```sh
        $ pulumi import bytepluscc:autoscaling/scalingGroup:ScalingGroup example "scaling_group_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] active_scaling_configuration_id: 伸缩组绑定的伸缩配置的ID。
        :param pulumi.Input[builtins.int] default_cooldown: 执行一次伸缩活动（添加或移出ECS实例）结束后的冷却时间。冷却时间内，该伸缩组不执行其它的伸缩活动，仅针对云监控报警任务触发的伸缩活动和伸缩规则有效。取值范围：5 ~ 86400，单位：秒。默认值：300。
        :param pulumi.Input[builtins.int] desire_instance_number: 伸缩组中期望运行的实例个数。1、不小于最小实例数MinInstanceNumber且不大于最大实例数MaxInstanceNumber。2、默认值：-1，表示不开启期望实例数能力。此时，伸缩组创建完成后会立即开始伸缩活动自动添加相应个数的实例。
        :param pulumi.Input[builtins.str] health_check_type: 伸缩组的健康检查方式。1、NONE：不做实例健康状态检查。2、ECS（默认）：对伸缩组内的ECS实例做健康检查。
        :param pulumi.Input[builtins.str] instance_terminate_policy: 实例移除策略，1、OldestInstance：移出最早加入 （包括自动创建和手动添加）伸缩组的实例。2、NewestInstance：移出最晚加入（包括自动创建和手动添加）伸缩组的实例。3、OldestScalingConfigurationWithOldestInstance（默认）：移出最早与伸缩组绑定的伸缩配置中，最早由伸缩组 自动创建 的实例。4、OldestScalingConfigurationWithNewestInstance：移出最早与伸缩组绑定的伸缩配置中，最晚由伸缩组 自动创建 的实例。
        :param pulumi.Input[Union['ScalingGroupInstancesDistributionArgs', 'ScalingGroupInstancesDistributionArgsDict']] instances_distribution: 实例分布策略。
        :param pulumi.Input[builtins.bool] is_enable_scaling_group: 是否启用伸缩组。true：启用。false：停止
        :param pulumi.Input[builtins.str] launch_template_id: 实例启动模板ID，配置后表示选择启动模版作为伸缩配置来源。
        :param pulumi.Input[builtins.str] launch_template_version: 实例启动模板的版本。1、模板的某个版本号。2、Default（默认）：始终使用模板默认版本。3、Latest：始终使用模板最新版本。
        :param pulumi.Input[builtins.int] max_instance_number: 伸缩组中实例个数的最大值，默认取值0 ～ 100。您可以通过配额中心调整。
        :param pulumi.Input[builtins.int] min_instance_number: 伸缩组中实例个数的最小值，默认取值0 ～ 100。您可以通过配额中心调整。
        :param pulumi.Input[builtins.str] multi_az_policy: 扩缩容策略，如果您选择了多个子网，需配置本参数。1、PRIORITY（默认）：优先级策略。2、BALANCE：均衡分布策略。
        :param pulumi.Input[builtins.str] project_name: 伸缩组所属项目，默认为default。一个资源只能归属于一个项目。只能包含字母、数字、下划线“_”、点“.”和中划线“-”。长度限制在64个字符以内。
        :param pulumi.Input[builtins.str] scaling_group_name: 伸缩组名称，同一地域下伸缩组名称唯一。只能以中文、字母开头，只能包含中文、字母、数字、下划线和中划线 。长度限制为1 ~ 128个字符。暂不支持特殊字符。
        :param pulumi.Input[builtins.str] scaling_mode: 伸缩组的实例回收模式。1、release（默认）：释放模式。2、recycle：停机回收模式。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] subnet_ids: 伸缩组中实例主网卡的子网ID列表。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] suspended_processes: 暂停中的流程，无暂停中流程则返回空值。ScaleIn：缩容流程。ScaleOut：扩容流程。HealthCheck：健康检查。AlarmNotification：报警任务。ScheduledAction：定时任务。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ScalingGroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        伸缩组用于管理一组云资源实例。通过伸缩组可以定义云资源池中的实例数/容量、冷却时间、负载均衡等信息。

        ## Import

        ```sh
        $ pulumi import bytepluscc:autoscaling/scalingGroup:ScalingGroup example "scaling_group_id"
        ```

        :param str resource_name: The name of the resource.
        :param ScalingGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ScalingGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 active_scaling_configuration_id: Optional[pulumi.Input[builtins.str]] = None,
                 default_cooldown: Optional[pulumi.Input[builtins.int]] = None,
                 desire_instance_number: Optional[pulumi.Input[builtins.int]] = None,
                 health_check_type: Optional[pulumi.Input[builtins.str]] = None,
                 instance_terminate_policy: Optional[pulumi.Input[builtins.str]] = None,
                 instances_distribution: Optional[pulumi.Input[Union['ScalingGroupInstancesDistributionArgs', 'ScalingGroupInstancesDistributionArgsDict']]] = None,
                 is_enable_scaling_group: Optional[pulumi.Input[builtins.bool]] = None,
                 launch_template_id: Optional[pulumi.Input[builtins.str]] = None,
                 launch_template_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ScalingGroupLaunchTemplateOverrideArgs', 'ScalingGroupLaunchTemplateOverrideArgsDict']]]]] = None,
                 launch_template_version: Optional[pulumi.Input[builtins.str]] = None,
                 max_instance_number: Optional[pulumi.Input[builtins.int]] = None,
                 min_instance_number: Optional[pulumi.Input[builtins.int]] = None,
                 multi_az_policy: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 scaling_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 scaling_mode: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_attributes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ScalingGroupServerGroupAttributeArgs', 'ScalingGroupServerGroupAttributeArgsDict']]]]] = None,
                 subnet_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 suspended_processes: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ScalingGroupTagArgs', 'ScalingGroupTagArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ScalingGroupArgs.__new__(ScalingGroupArgs)

            __props__.__dict__["active_scaling_configuration_id"] = active_scaling_configuration_id
            __props__.__dict__["default_cooldown"] = default_cooldown
            __props__.__dict__["desire_instance_number"] = desire_instance_number
            __props__.__dict__["health_check_type"] = health_check_type
            __props__.__dict__["instance_terminate_policy"] = instance_terminate_policy
            __props__.__dict__["instances_distribution"] = instances_distribution
            __props__.__dict__["is_enable_scaling_group"] = is_enable_scaling_group
            __props__.__dict__["launch_template_id"] = launch_template_id
            __props__.__dict__["launch_template_overrides"] = launch_template_overrides
            __props__.__dict__["launch_template_version"] = launch_template_version
            if max_instance_number is None and not opts.urn:
                raise TypeError("Missing required property 'max_instance_number'")
            __props__.__dict__["max_instance_number"] = max_instance_number
            if min_instance_number is None and not opts.urn:
                raise TypeError("Missing required property 'min_instance_number'")
            __props__.__dict__["min_instance_number"] = min_instance_number
            __props__.__dict__["multi_az_policy"] = multi_az_policy
            __props__.__dict__["project_name"] = project_name
            if scaling_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'scaling_group_name'")
            __props__.__dict__["scaling_group_name"] = scaling_group_name
            __props__.__dict__["scaling_mode"] = scaling_mode
            __props__.__dict__["server_group_attributes"] = server_group_attributes
            if subnet_ids is None and not opts.urn:
                raise TypeError("Missing required property 'subnet_ids'")
            __props__.__dict__["subnet_ids"] = subnet_ids
            __props__.__dict__["suspended_processes"] = suspended_processes
            __props__.__dict__["tags"] = tags
            __props__.__dict__["created_time"] = None
            __props__.__dict__["db_instance_ids"] = None
            __props__.__dict__["lifecycle_state"] = None
            __props__.__dict__["load_balancer_health_check_grace_period"] = None
            __props__.__dict__["scaling_group_id"] = None
            __props__.__dict__["stopped_instance_count"] = None
            __props__.__dict__["total_instance_count"] = None
            __props__.__dict__["updated_time"] = None
            __props__.__dict__["vpc_id"] = None
        super(ScalingGroup, __self__).__init__(
            'bytepluscc:autoscaling/scalingGroup:ScalingGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            active_scaling_configuration_id: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            db_instance_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            default_cooldown: Optional[pulumi.Input[builtins.int]] = None,
            desire_instance_number: Optional[pulumi.Input[builtins.int]] = None,
            health_check_type: Optional[pulumi.Input[builtins.str]] = None,
            instance_terminate_policy: Optional[pulumi.Input[builtins.str]] = None,
            instances_distribution: Optional[pulumi.Input[Union['ScalingGroupInstancesDistributionArgs', 'ScalingGroupInstancesDistributionArgsDict']]] = None,
            is_enable_scaling_group: Optional[pulumi.Input[builtins.bool]] = None,
            launch_template_id: Optional[pulumi.Input[builtins.str]] = None,
            launch_template_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ScalingGroupLaunchTemplateOverrideArgs', 'ScalingGroupLaunchTemplateOverrideArgsDict']]]]] = None,
            launch_template_version: Optional[pulumi.Input[builtins.str]] = None,
            lifecycle_state: Optional[pulumi.Input[builtins.str]] = None,
            load_balancer_health_check_grace_period: Optional[pulumi.Input[builtins.int]] = None,
            max_instance_number: Optional[pulumi.Input[builtins.int]] = None,
            min_instance_number: Optional[pulumi.Input[builtins.int]] = None,
            multi_az_policy: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            scaling_group_id: Optional[pulumi.Input[builtins.str]] = None,
            scaling_group_name: Optional[pulumi.Input[builtins.str]] = None,
            scaling_mode: Optional[pulumi.Input[builtins.str]] = None,
            server_group_attributes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ScalingGroupServerGroupAttributeArgs', 'ScalingGroupServerGroupAttributeArgsDict']]]]] = None,
            stopped_instance_count: Optional[pulumi.Input[builtins.int]] = None,
            subnet_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            suspended_processes: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ScalingGroupTagArgs', 'ScalingGroupTagArgsDict']]]]] = None,
            total_instance_count: Optional[pulumi.Input[builtins.int]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None) -> 'ScalingGroup':
        """
        Get an existing ScalingGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] active_scaling_configuration_id: 伸缩组绑定的伸缩配置的ID。
        :param pulumi.Input[builtins.str] created_time: 伸缩组创建时间。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] db_instance_ids: RDS数据库实例的ID。
        :param pulumi.Input[builtins.int] default_cooldown: 执行一次伸缩活动（添加或移出ECS实例）结束后的冷却时间。冷却时间内，该伸缩组不执行其它的伸缩活动，仅针对云监控报警任务触发的伸缩活动和伸缩规则有效。取值范围：5 ~ 86400，单位：秒。默认值：300。
        :param pulumi.Input[builtins.int] desire_instance_number: 伸缩组中期望运行的实例个数。1、不小于最小实例数MinInstanceNumber且不大于最大实例数MaxInstanceNumber。2、默认值：-1，表示不开启期望实例数能力。此时，伸缩组创建完成后会立即开始伸缩活动自动添加相应个数的实例。
        :param pulumi.Input[builtins.str] health_check_type: 伸缩组的健康检查方式。1、NONE：不做实例健康状态检查。2、ECS（默认）：对伸缩组内的ECS实例做健康检查。
        :param pulumi.Input[builtins.str] instance_terminate_policy: 实例移除策略，1、OldestInstance：移出最早加入 （包括自动创建和手动添加）伸缩组的实例。2、NewestInstance：移出最晚加入（包括自动创建和手动添加）伸缩组的实例。3、OldestScalingConfigurationWithOldestInstance（默认）：移出最早与伸缩组绑定的伸缩配置中，最早由伸缩组 自动创建 的实例。4、OldestScalingConfigurationWithNewestInstance：移出最早与伸缩组绑定的伸缩配置中，最晚由伸缩组 自动创建 的实例。
        :param pulumi.Input[Union['ScalingGroupInstancesDistributionArgs', 'ScalingGroupInstancesDistributionArgsDict']] instances_distribution: 实例分布策略。
        :param pulumi.Input[builtins.bool] is_enable_scaling_group: 是否启用伸缩组。true：启用。false：停止
        :param pulumi.Input[builtins.str] launch_template_id: 实例启动模板ID，配置后表示选择启动模版作为伸缩配置来源。
        :param pulumi.Input[builtins.str] launch_template_version: 实例启动模板的版本。1、模板的某个版本号。2、Default（默认）：始终使用模板默认版本。3、Latest：始终使用模板最新版本。
        :param pulumi.Input[builtins.str] lifecycle_state: 伸缩组的状态。Active：已启用。InActive：未激活。Deleting：删除中。Locked: 已锁定。CoolingDown: 冷却中。Unknown: 未知状态。
        :param pulumi.Input[builtins.int] load_balancer_health_check_grace_period: 伸缩组实例CLB健康状况检查宽限期。
        :param pulumi.Input[builtins.int] max_instance_number: 伸缩组中实例个数的最大值，默认取值0 ～ 100。您可以通过配额中心调整。
        :param pulumi.Input[builtins.int] min_instance_number: 伸缩组中实例个数的最小值，默认取值0 ～ 100。您可以通过配额中心调整。
        :param pulumi.Input[builtins.str] multi_az_policy: 扩缩容策略，如果您选择了多个子网，需配置本参数。1、PRIORITY（默认）：优先级策略。2、BALANCE：均衡分布策略。
        :param pulumi.Input[builtins.str] project_name: 伸缩组所属项目，默认为default。一个资源只能归属于一个项目。只能包含字母、数字、下划线“_”、点“.”和中划线“-”。长度限制在64个字符以内。
        :param pulumi.Input[builtins.str] scaling_group_id: 伸缩组ID。
        :param pulumi.Input[builtins.str] scaling_group_name: 伸缩组名称，同一地域下伸缩组名称唯一。只能以中文、字母开头，只能包含中文、字母、数字、下划线和中划线 。长度限制为1 ~ 128个字符。暂不支持特殊字符。
        :param pulumi.Input[builtins.str] scaling_mode: 伸缩组的实例回收模式。1、release（默认）：释放模式。2、recycle：停机回收模式。
        :param pulumi.Input[builtins.int] stopped_instance_count: 伸缩组内处于停用中状态的实例数量。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] subnet_ids: 伸缩组中实例主网卡的子网ID列表。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] suspended_processes: 暂停中的流程，无暂停中流程则返回空值。ScaleIn：缩容流程。ScaleOut：扩容流程。HealthCheck：健康检查。AlarmNotification：报警任务。ScheduledAction：定时任务。
        :param pulumi.Input[builtins.int] total_instance_count: 当前伸缩组内实例的个数。
        :param pulumi.Input[builtins.str] updated_time: 伸缩组更新时间。
        :param pulumi.Input[builtins.str] vpc_id: 伸缩组所属私有网络ID。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ScalingGroupState.__new__(_ScalingGroupState)

        __props__.__dict__["active_scaling_configuration_id"] = active_scaling_configuration_id
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["db_instance_ids"] = db_instance_ids
        __props__.__dict__["default_cooldown"] = default_cooldown
        __props__.__dict__["desire_instance_number"] = desire_instance_number
        __props__.__dict__["health_check_type"] = health_check_type
        __props__.__dict__["instance_terminate_policy"] = instance_terminate_policy
        __props__.__dict__["instances_distribution"] = instances_distribution
        __props__.__dict__["is_enable_scaling_group"] = is_enable_scaling_group
        __props__.__dict__["launch_template_id"] = launch_template_id
        __props__.__dict__["launch_template_overrides"] = launch_template_overrides
        __props__.__dict__["launch_template_version"] = launch_template_version
        __props__.__dict__["lifecycle_state"] = lifecycle_state
        __props__.__dict__["load_balancer_health_check_grace_period"] = load_balancer_health_check_grace_period
        __props__.__dict__["max_instance_number"] = max_instance_number
        __props__.__dict__["min_instance_number"] = min_instance_number
        __props__.__dict__["multi_az_policy"] = multi_az_policy
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["scaling_group_id"] = scaling_group_id
        __props__.__dict__["scaling_group_name"] = scaling_group_name
        __props__.__dict__["scaling_mode"] = scaling_mode
        __props__.__dict__["server_group_attributes"] = server_group_attributes
        __props__.__dict__["stopped_instance_count"] = stopped_instance_count
        __props__.__dict__["subnet_ids"] = subnet_ids
        __props__.__dict__["suspended_processes"] = suspended_processes
        __props__.__dict__["tags"] = tags
        __props__.__dict__["total_instance_count"] = total_instance_count
        __props__.__dict__["updated_time"] = updated_time
        __props__.__dict__["vpc_id"] = vpc_id
        return ScalingGroup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="activeScalingConfigurationId")
    def active_scaling_configuration_id(self) -> pulumi.Output[builtins.str]:
        """
        伸缩组绑定的伸缩配置的ID。
        """
        return pulumi.get(self, "active_scaling_configuration_id")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        伸缩组创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="dbInstanceIds")
    def db_instance_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        RDS数据库实例的ID。
        """
        return pulumi.get(self, "db_instance_ids")

    @property
    @pulumi.getter(name="defaultCooldown")
    def default_cooldown(self) -> pulumi.Output[builtins.int]:
        """
        执行一次伸缩活动（添加或移出ECS实例）结束后的冷却时间。冷却时间内，该伸缩组不执行其它的伸缩活动，仅针对云监控报警任务触发的伸缩活动和伸缩规则有效。取值范围：5 ~ 86400，单位：秒。默认值：300。
        """
        return pulumi.get(self, "default_cooldown")

    @property
    @pulumi.getter(name="desireInstanceNumber")
    def desire_instance_number(self) -> pulumi.Output[builtins.int]:
        """
        伸缩组中期望运行的实例个数。1、不小于最小实例数MinInstanceNumber且不大于最大实例数MaxInstanceNumber。2、默认值：-1，表示不开启期望实例数能力。此时，伸缩组创建完成后会立即开始伸缩活动自动添加相应个数的实例。
        """
        return pulumi.get(self, "desire_instance_number")

    @property
    @pulumi.getter(name="healthCheckType")
    def health_check_type(self) -> pulumi.Output[builtins.str]:
        """
        伸缩组的健康检查方式。1、NONE：不做实例健康状态检查。2、ECS（默认）：对伸缩组内的ECS实例做健康检查。
        """
        return pulumi.get(self, "health_check_type")

    @property
    @pulumi.getter(name="instanceTerminatePolicy")
    def instance_terminate_policy(self) -> pulumi.Output[builtins.str]:
        """
        实例移除策略，1、OldestInstance：移出最早加入 （包括自动创建和手动添加）伸缩组的实例。2、NewestInstance：移出最晚加入（包括自动创建和手动添加）伸缩组的实例。3、OldestScalingConfigurationWithOldestInstance（默认）：移出最早与伸缩组绑定的伸缩配置中，最早由伸缩组 自动创建 的实例。4、OldestScalingConfigurationWithNewestInstance：移出最早与伸缩组绑定的伸缩配置中，最晚由伸缩组 自动创建 的实例。
        """
        return pulumi.get(self, "instance_terminate_policy")

    @property
    @pulumi.getter(name="instancesDistribution")
    def instances_distribution(self) -> pulumi.Output['outputs.ScalingGroupInstancesDistribution']:
        """
        实例分布策略。
        """
        return pulumi.get(self, "instances_distribution")

    @property
    @pulumi.getter(name="isEnableScalingGroup")
    def is_enable_scaling_group(self) -> pulumi.Output[builtins.bool]:
        """
        是否启用伸缩组。true：启用。false：停止
        """
        return pulumi.get(self, "is_enable_scaling_group")

    @property
    @pulumi.getter(name="launchTemplateId")
    def launch_template_id(self) -> pulumi.Output[builtins.str]:
        """
        实例启动模板ID，配置后表示选择启动模版作为伸缩配置来源。
        """
        return pulumi.get(self, "launch_template_id")

    @property
    @pulumi.getter(name="launchTemplateOverrides")
    def launch_template_overrides(self) -> pulumi.Output[Sequence['outputs.ScalingGroupLaunchTemplateOverride']]:
        return pulumi.get(self, "launch_template_overrides")

    @property
    @pulumi.getter(name="launchTemplateVersion")
    def launch_template_version(self) -> pulumi.Output[builtins.str]:
        """
        实例启动模板的版本。1、模板的某个版本号。2、Default（默认）：始终使用模板默认版本。3、Latest：始终使用模板最新版本。
        """
        return pulumi.get(self, "launch_template_version")

    @property
    @pulumi.getter(name="lifecycleState")
    def lifecycle_state(self) -> pulumi.Output[builtins.str]:
        """
        伸缩组的状态。Active：已启用。InActive：未激活。Deleting：删除中。Locked: 已锁定。CoolingDown: 冷却中。Unknown: 未知状态。
        """
        return pulumi.get(self, "lifecycle_state")

    @property
    @pulumi.getter(name="loadBalancerHealthCheckGracePeriod")
    def load_balancer_health_check_grace_period(self) -> pulumi.Output[builtins.int]:
        """
        伸缩组实例CLB健康状况检查宽限期。
        """
        return pulumi.get(self, "load_balancer_health_check_grace_period")

    @property
    @pulumi.getter(name="maxInstanceNumber")
    def max_instance_number(self) -> pulumi.Output[builtins.int]:
        """
        伸缩组中实例个数的最大值，默认取值0 ～ 100。您可以通过配额中心调整。
        """
        return pulumi.get(self, "max_instance_number")

    @property
    @pulumi.getter(name="minInstanceNumber")
    def min_instance_number(self) -> pulumi.Output[builtins.int]:
        """
        伸缩组中实例个数的最小值，默认取值0 ～ 100。您可以通过配额中心调整。
        """
        return pulumi.get(self, "min_instance_number")

    @property
    @pulumi.getter(name="multiAzPolicy")
    def multi_az_policy(self) -> pulumi.Output[builtins.str]:
        """
        扩缩容策略，如果您选择了多个子网，需配置本参数。1、PRIORITY（默认）：优先级策略。2、BALANCE：均衡分布策略。
        """
        return pulumi.get(self, "multi_az_policy")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        伸缩组所属项目，默认为default。一个资源只能归属于一个项目。只能包含字母、数字、下划线“_”、点“.”和中划线“-”。长度限制在64个字符以内。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="scalingGroupId")
    def scaling_group_id(self) -> pulumi.Output[builtins.str]:
        """
        伸缩组ID。
        """
        return pulumi.get(self, "scaling_group_id")

    @property
    @pulumi.getter(name="scalingGroupName")
    def scaling_group_name(self) -> pulumi.Output[builtins.str]:
        """
        伸缩组名称，同一地域下伸缩组名称唯一。只能以中文、字母开头，只能包含中文、字母、数字、下划线和中划线 。长度限制为1 ~ 128个字符。暂不支持特殊字符。
        """
        return pulumi.get(self, "scaling_group_name")

    @property
    @pulumi.getter(name="scalingMode")
    def scaling_mode(self) -> pulumi.Output[builtins.str]:
        """
        伸缩组的实例回收模式。1、release（默认）：释放模式。2、recycle：停机回收模式。
        """
        return pulumi.get(self, "scaling_mode")

    @property
    @pulumi.getter(name="serverGroupAttributes")
    def server_group_attributes(self) -> pulumi.Output[Sequence['outputs.ScalingGroupServerGroupAttribute']]:
        return pulumi.get(self, "server_group_attributes")

    @property
    @pulumi.getter(name="stoppedInstanceCount")
    def stopped_instance_count(self) -> pulumi.Output[builtins.int]:
        """
        伸缩组内处于停用中状态的实例数量。
        """
        return pulumi.get(self, "stopped_instance_count")

    @property
    @pulumi.getter(name="subnetIds")
    def subnet_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        伸缩组中实例主网卡的子网ID列表。
        """
        return pulumi.get(self, "subnet_ids")

    @property
    @pulumi.getter(name="suspendedProcesses")
    def suspended_processes(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        暂停中的流程，无暂停中流程则返回空值。ScaleIn：缩容流程。ScaleOut：扩容流程。HealthCheck：健康检查。AlarmNotification：报警任务。ScheduledAction：定时任务。
        """
        return pulumi.get(self, "suspended_processes")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.ScalingGroupTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="totalInstanceCount")
    def total_instance_count(self) -> pulumi.Output[builtins.int]:
        """
        当前伸缩组内实例的个数。
        """
        return pulumi.get(self, "total_instance_count")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        伸缩组更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        伸缩组所属私有网络ID。
        """
        return pulumi.get(self, "vpc_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NodePoolArgs', 'NodePool']

@pulumi.input_type
class NodePoolArgs:
    def __init__(__self__, *,
                 cluster_id: pulumi.Input[builtins.str],
                 auto_scaling: Optional[pulumi.Input['NodePoolAutoScalingArgs']] = None,
                 kubernetes_config: Optional[pulumi.Input['NodePoolKubernetesConfigArgs']] = None,
                 management: Optional[pulumi.Input['NodePoolManagementArgs']] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 node_config: Optional[pulumi.Input['NodePoolNodeConfigArgs']] = None,
                 retain_resources: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['NodePoolTagArgs']]]] = None):
        """
        The set of arguments for constructing a NodePool resource.
        :param pulumi.Input[builtins.str] cluster_id: 节点池所在集群的 ID。
        :param pulumi.Input['NodePoolAutoScalingArgs'] auto_scaling: 节点池伸缩策略配置。
        :param pulumi.Input['NodePoolKubernetesConfigArgs'] kubernetes_config: 节点池 Kubernetes 相关配置。
        :param pulumi.Input['NodePoolManagementArgs'] management: 托管节点池配置。
        :param pulumi.Input[builtins.str] name: 节点池名称。同一个集群下，节点池名称必须唯一。支持大小写英文字母、汉字、数字、短划线（-），长度限制为 2～64 个字符。
        :param pulumi.Input['NodePoolNodeConfigArgs'] node_config: 节点池中云服务器（ECS）实例配置。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] retain_resources: 删除节点池时，指定保留的相关资源，取值：取值为空：（默认值）删除关联资源。Ecs：删除节点池时，保留节点池中的云服务器（ECS）实例。若指定的节点池内存在包年包月的云服务器实例，且未选择保留云服务器，则该接口仅从节点池中移除云服务器实例，不会删除。您可以通过云服务器控制台或云服务器API查询到该实例，并按需执行后续操作。
        """
        pulumi.set(__self__, "cluster_id", cluster_id)
        if auto_scaling is not None:
            pulumi.set(__self__, "auto_scaling", auto_scaling)
        if kubernetes_config is not None:
            pulumi.set(__self__, "kubernetes_config", kubernetes_config)
        if management is not None:
            pulumi.set(__self__, "management", management)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if node_config is not None:
            pulumi.set(__self__, "node_config", node_config)
        if retain_resources is not None:
            pulumi.set(__self__, "retain_resources", retain_resources)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Input[builtins.str]:
        """
        节点池所在集群的 ID。
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="autoScaling")
    def auto_scaling(self) -> Optional[pulumi.Input['NodePoolAutoScalingArgs']]:
        """
        节点池伸缩策略配置。
        """
        return pulumi.get(self, "auto_scaling")

    @auto_scaling.setter
    def auto_scaling(self, value: Optional[pulumi.Input['NodePoolAutoScalingArgs']]):
        pulumi.set(self, "auto_scaling", value)

    @property
    @pulumi.getter(name="kubernetesConfig")
    def kubernetes_config(self) -> Optional[pulumi.Input['NodePoolKubernetesConfigArgs']]:
        """
        节点池 Kubernetes 相关配置。
        """
        return pulumi.get(self, "kubernetes_config")

    @kubernetes_config.setter
    def kubernetes_config(self, value: Optional[pulumi.Input['NodePoolKubernetesConfigArgs']]):
        pulumi.set(self, "kubernetes_config", value)

    @property
    @pulumi.getter
    def management(self) -> Optional[pulumi.Input['NodePoolManagementArgs']]:
        """
        托管节点池配置。
        """
        return pulumi.get(self, "management")

    @management.setter
    def management(self, value: Optional[pulumi.Input['NodePoolManagementArgs']]):
        pulumi.set(self, "management", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        节点池名称。同一个集群下，节点池名称必须唯一。支持大小写英文字母、汉字、数字、短划线（-），长度限制为 2～64 个字符。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="nodeConfig")
    def node_config(self) -> Optional[pulumi.Input['NodePoolNodeConfigArgs']]:
        """
        节点池中云服务器（ECS）实例配置。
        """
        return pulumi.get(self, "node_config")

    @node_config.setter
    def node_config(self, value: Optional[pulumi.Input['NodePoolNodeConfigArgs']]):
        pulumi.set(self, "node_config", value)

    @property
    @pulumi.getter(name="retainResources")
    def retain_resources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        删除节点池时，指定保留的相关资源，取值：取值为空：（默认值）删除关联资源。Ecs：删除节点池时，保留节点池中的云服务器（ECS）实例。若指定的节点池内存在包年包月的云服务器实例，且未选择保留云服务器，则该接口仅从节点池中移除云服务器实例，不会删除。您可以通过云服务器控制台或云服务器API查询到该实例，并按需执行后续操作。
        """
        return pulumi.get(self, "retain_resources")

    @retain_resources.setter
    def retain_resources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "retain_resources", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NodePoolTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NodePoolTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _NodePoolState:
    def __init__(__self__, *,
                 auto_scaling: Optional[pulumi.Input['NodePoolAutoScalingArgs']] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 kubernetes_config: Optional[pulumi.Input['NodePoolKubernetesConfigArgs']] = None,
                 management: Optional[pulumi.Input['NodePoolManagementArgs']] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 node_config: Optional[pulumi.Input['NodePoolNodeConfigArgs']] = None,
                 node_pool_id: Optional[pulumi.Input[builtins.str]] = None,
                 node_statistics: Optional[pulumi.Input['NodePoolNodeStatisticsArgs']] = None,
                 retain_resources: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 status: Optional[pulumi.Input['NodePoolStatusArgs']] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['NodePoolTagArgs']]]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering NodePool resources.
        :param pulumi.Input['NodePoolAutoScalingArgs'] auto_scaling: 节点池伸缩策略配置。
        :param pulumi.Input[builtins.str] cluster_id: 节点池所在集群的 ID。
        :param pulumi.Input[builtins.str] created_time: 创建节点池的时间。
        :param pulumi.Input['NodePoolKubernetesConfigArgs'] kubernetes_config: 节点池 Kubernetes 相关配置。
        :param pulumi.Input['NodePoolManagementArgs'] management: 托管节点池配置。
        :param pulumi.Input[builtins.str] name: 节点池名称。同一个集群下，节点池名称必须唯一。支持大小写英文字母、汉字、数字、短划线（-），长度限制为 2～64 个字符。
        :param pulumi.Input['NodePoolNodeConfigArgs'] node_config: 节点池中云服务器（ECS）实例配置。
        :param pulumi.Input[builtins.str] node_pool_id: 节点池 ID 。
        :param pulumi.Input['NodePoolNodeStatisticsArgs'] node_statistics: 节点池中的节点统计。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] retain_resources: 删除节点池时，指定保留的相关资源，取值：取值为空：（默认值）删除关联资源。Ecs：删除节点池时，保留节点池中的云服务器（ECS）实例。若指定的节点池内存在包年包月的云服务器实例，且未选择保留云服务器，则该接口仅从节点池中移除云服务器实例，不会删除。您可以通过云服务器控制台或云服务器API查询到该实例，并按需执行后续操作。
        :param pulumi.Input['NodePoolStatusArgs'] status: 节点池状态。
        :param pulumi.Input[builtins.str] updated_time: 更新节点池的时间。
        """
        if auto_scaling is not None:
            pulumi.set(__self__, "auto_scaling", auto_scaling)
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if kubernetes_config is not None:
            pulumi.set(__self__, "kubernetes_config", kubernetes_config)
        if management is not None:
            pulumi.set(__self__, "management", management)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if node_config is not None:
            pulumi.set(__self__, "node_config", node_config)
        if node_pool_id is not None:
            pulumi.set(__self__, "node_pool_id", node_pool_id)
        if node_statistics is not None:
            pulumi.set(__self__, "node_statistics", node_statistics)
        if retain_resources is not None:
            pulumi.set(__self__, "retain_resources", retain_resources)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="autoScaling")
    def auto_scaling(self) -> Optional[pulumi.Input['NodePoolAutoScalingArgs']]:
        """
        节点池伸缩策略配置。
        """
        return pulumi.get(self, "auto_scaling")

    @auto_scaling.setter
    def auto_scaling(self, value: Optional[pulumi.Input['NodePoolAutoScalingArgs']]):
        pulumi.set(self, "auto_scaling", value)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        节点池所在集群的 ID。
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建节点池的时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="kubernetesConfig")
    def kubernetes_config(self) -> Optional[pulumi.Input['NodePoolKubernetesConfigArgs']]:
        """
        节点池 Kubernetes 相关配置。
        """
        return pulumi.get(self, "kubernetes_config")

    @kubernetes_config.setter
    def kubernetes_config(self, value: Optional[pulumi.Input['NodePoolKubernetesConfigArgs']]):
        pulumi.set(self, "kubernetes_config", value)

    @property
    @pulumi.getter
    def management(self) -> Optional[pulumi.Input['NodePoolManagementArgs']]:
        """
        托管节点池配置。
        """
        return pulumi.get(self, "management")

    @management.setter
    def management(self, value: Optional[pulumi.Input['NodePoolManagementArgs']]):
        pulumi.set(self, "management", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        节点池名称。同一个集群下，节点池名称必须唯一。支持大小写英文字母、汉字、数字、短划线（-），长度限制为 2～64 个字符。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="nodeConfig")
    def node_config(self) -> Optional[pulumi.Input['NodePoolNodeConfigArgs']]:
        """
        节点池中云服务器（ECS）实例配置。
        """
        return pulumi.get(self, "node_config")

    @node_config.setter
    def node_config(self, value: Optional[pulumi.Input['NodePoolNodeConfigArgs']]):
        pulumi.set(self, "node_config", value)

    @property
    @pulumi.getter(name="nodePoolId")
    def node_pool_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        节点池 ID 。
        """
        return pulumi.get(self, "node_pool_id")

    @node_pool_id.setter
    def node_pool_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "node_pool_id", value)

    @property
    @pulumi.getter(name="nodeStatistics")
    def node_statistics(self) -> Optional[pulumi.Input['NodePoolNodeStatisticsArgs']]:
        """
        节点池中的节点统计。
        """
        return pulumi.get(self, "node_statistics")

    @node_statistics.setter
    def node_statistics(self, value: Optional[pulumi.Input['NodePoolNodeStatisticsArgs']]):
        pulumi.set(self, "node_statistics", value)

    @property
    @pulumi.getter(name="retainResources")
    def retain_resources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        删除节点池时，指定保留的相关资源，取值：取值为空：（默认值）删除关联资源。Ecs：删除节点池时，保留节点池中的云服务器（ECS）实例。若指定的节点池内存在包年包月的云服务器实例，且未选择保留云服务器，则该接口仅从节点池中移除云服务器实例，不会删除。您可以通过云服务器控制台或云服务器API查询到该实例，并按需执行后续操作。
        """
        return pulumi.get(self, "retain_resources")

    @retain_resources.setter
    def retain_resources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "retain_resources", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input['NodePoolStatusArgs']]:
        """
        节点池状态。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input['NodePoolStatusArgs']]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NodePoolTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NodePoolTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        更新节点池的时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)


@pulumi.type_token("bytepluscc:vke/nodePool:NodePool")
class NodePool(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_scaling: Optional[pulumi.Input[Union['NodePoolAutoScalingArgs', 'NodePoolAutoScalingArgsDict']]] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 kubernetes_config: Optional[pulumi.Input[Union['NodePoolKubernetesConfigArgs', 'NodePoolKubernetesConfigArgsDict']]] = None,
                 management: Optional[pulumi.Input[Union['NodePoolManagementArgs', 'NodePoolManagementArgsDict']]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 node_config: Optional[pulumi.Input[Union['NodePoolNodeConfigArgs', 'NodePoolNodeConfigArgsDict']]] = None,
                 retain_resources: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NodePoolTagArgs', 'NodePoolTagArgsDict']]]]] = None,
                 __props__=None):
        """
        节点池是集群中具有相同配置的一组节点，一个节点池包含一个节点或多个节点。节点池的配置包含节点的属性，例如节点规格、可用区、标签、污点等。这些属性可以在创建节点池时指定，也可以在创建完成后进行编辑修改。

        ## Import

        ```sh
        $ pulumi import bytepluscc:vke/nodePool:NodePool example "cluster_id|node_pool_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['NodePoolAutoScalingArgs', 'NodePoolAutoScalingArgsDict']] auto_scaling: 节点池伸缩策略配置。
        :param pulumi.Input[builtins.str] cluster_id: 节点池所在集群的 ID。
        :param pulumi.Input[Union['NodePoolKubernetesConfigArgs', 'NodePoolKubernetesConfigArgsDict']] kubernetes_config: 节点池 Kubernetes 相关配置。
        :param pulumi.Input[Union['NodePoolManagementArgs', 'NodePoolManagementArgsDict']] management: 托管节点池配置。
        :param pulumi.Input[builtins.str] name: 节点池名称。同一个集群下，节点池名称必须唯一。支持大小写英文字母、汉字、数字、短划线（-），长度限制为 2～64 个字符。
        :param pulumi.Input[Union['NodePoolNodeConfigArgs', 'NodePoolNodeConfigArgsDict']] node_config: 节点池中云服务器（ECS）实例配置。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] retain_resources: 删除节点池时，指定保留的相关资源，取值：取值为空：（默认值）删除关联资源。Ecs：删除节点池时，保留节点池中的云服务器（ECS）实例。若指定的节点池内存在包年包月的云服务器实例，且未选择保留云服务器，则该接口仅从节点池中移除云服务器实例，不会删除。您可以通过云服务器控制台或云服务器API查询到该实例，并按需执行后续操作。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NodePoolArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        节点池是集群中具有相同配置的一组节点，一个节点池包含一个节点或多个节点。节点池的配置包含节点的属性，例如节点规格、可用区、标签、污点等。这些属性可以在创建节点池时指定，也可以在创建完成后进行编辑修改。

        ## Import

        ```sh
        $ pulumi import bytepluscc:vke/nodePool:NodePool example "cluster_id|node_pool_id"
        ```

        :param str resource_name: The name of the resource.
        :param NodePoolArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NodePoolArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_scaling: Optional[pulumi.Input[Union['NodePoolAutoScalingArgs', 'NodePoolAutoScalingArgsDict']]] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 kubernetes_config: Optional[pulumi.Input[Union['NodePoolKubernetesConfigArgs', 'NodePoolKubernetesConfigArgsDict']]] = None,
                 management: Optional[pulumi.Input[Union['NodePoolManagementArgs', 'NodePoolManagementArgsDict']]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 node_config: Optional[pulumi.Input[Union['NodePoolNodeConfigArgs', 'NodePoolNodeConfigArgsDict']]] = None,
                 retain_resources: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NodePoolTagArgs', 'NodePoolTagArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NodePoolArgs.__new__(NodePoolArgs)

            __props__.__dict__["auto_scaling"] = auto_scaling
            if cluster_id is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_id'")
            __props__.__dict__["cluster_id"] = cluster_id
            __props__.__dict__["kubernetes_config"] = kubernetes_config
            __props__.__dict__["management"] = management
            __props__.__dict__["name"] = name
            __props__.__dict__["node_config"] = node_config
            __props__.__dict__["retain_resources"] = retain_resources
            __props__.__dict__["tags"] = tags
            __props__.__dict__["created_time"] = None
            __props__.__dict__["node_pool_id"] = None
            __props__.__dict__["node_statistics"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_time"] = None
        super(NodePool, __self__).__init__(
            'bytepluscc:vke/nodePool:NodePool',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auto_scaling: Optional[pulumi.Input[Union['NodePoolAutoScalingArgs', 'NodePoolAutoScalingArgsDict']]] = None,
            cluster_id: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            kubernetes_config: Optional[pulumi.Input[Union['NodePoolKubernetesConfigArgs', 'NodePoolKubernetesConfigArgsDict']]] = None,
            management: Optional[pulumi.Input[Union['NodePoolManagementArgs', 'NodePoolManagementArgsDict']]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            node_config: Optional[pulumi.Input[Union['NodePoolNodeConfigArgs', 'NodePoolNodeConfigArgsDict']]] = None,
            node_pool_id: Optional[pulumi.Input[builtins.str]] = None,
            node_statistics: Optional[pulumi.Input[Union['NodePoolNodeStatisticsArgs', 'NodePoolNodeStatisticsArgsDict']]] = None,
            retain_resources: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            status: Optional[pulumi.Input[Union['NodePoolStatusArgs', 'NodePoolStatusArgsDict']]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NodePoolTagArgs', 'NodePoolTagArgsDict']]]]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None) -> 'NodePool':
        """
        Get an existing NodePool resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['NodePoolAutoScalingArgs', 'NodePoolAutoScalingArgsDict']] auto_scaling: 节点池伸缩策略配置。
        :param pulumi.Input[builtins.str] cluster_id: 节点池所在集群的 ID。
        :param pulumi.Input[builtins.str] created_time: 创建节点池的时间。
        :param pulumi.Input[Union['NodePoolKubernetesConfigArgs', 'NodePoolKubernetesConfigArgsDict']] kubernetes_config: 节点池 Kubernetes 相关配置。
        :param pulumi.Input[Union['NodePoolManagementArgs', 'NodePoolManagementArgsDict']] management: 托管节点池配置。
        :param pulumi.Input[builtins.str] name: 节点池名称。同一个集群下，节点池名称必须唯一。支持大小写英文字母、汉字、数字、短划线（-），长度限制为 2～64 个字符。
        :param pulumi.Input[Union['NodePoolNodeConfigArgs', 'NodePoolNodeConfigArgsDict']] node_config: 节点池中云服务器（ECS）实例配置。
        :param pulumi.Input[builtins.str] node_pool_id: 节点池 ID 。
        :param pulumi.Input[Union['NodePoolNodeStatisticsArgs', 'NodePoolNodeStatisticsArgsDict']] node_statistics: 节点池中的节点统计。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] retain_resources: 删除节点池时，指定保留的相关资源，取值：取值为空：（默认值）删除关联资源。Ecs：删除节点池时，保留节点池中的云服务器（ECS）实例。若指定的节点池内存在包年包月的云服务器实例，且未选择保留云服务器，则该接口仅从节点池中移除云服务器实例，不会删除。您可以通过云服务器控制台或云服务器API查询到该实例，并按需执行后续操作。
        :param pulumi.Input[Union['NodePoolStatusArgs', 'NodePoolStatusArgsDict']] status: 节点池状态。
        :param pulumi.Input[builtins.str] updated_time: 更新节点池的时间。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NodePoolState.__new__(_NodePoolState)

        __props__.__dict__["auto_scaling"] = auto_scaling
        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["kubernetes_config"] = kubernetes_config
        __props__.__dict__["management"] = management
        __props__.__dict__["name"] = name
        __props__.__dict__["node_config"] = node_config
        __props__.__dict__["node_pool_id"] = node_pool_id
        __props__.__dict__["node_statistics"] = node_statistics
        __props__.__dict__["retain_resources"] = retain_resources
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_time"] = updated_time
        return NodePool(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="autoScaling")
    def auto_scaling(self) -> pulumi.Output['outputs.NodePoolAutoScaling']:
        """
        节点池伸缩策略配置。
        """
        return pulumi.get(self, "auto_scaling")

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[builtins.str]:
        """
        节点池所在集群的 ID。
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        创建节点池的时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="kubernetesConfig")
    def kubernetes_config(self) -> pulumi.Output['outputs.NodePoolKubernetesConfig']:
        """
        节点池 Kubernetes 相关配置。
        """
        return pulumi.get(self, "kubernetes_config")

    @property
    @pulumi.getter
    def management(self) -> pulumi.Output['outputs.NodePoolManagement']:
        """
        托管节点池配置。
        """
        return pulumi.get(self, "management")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        节点池名称。同一个集群下，节点池名称必须唯一。支持大小写英文字母、汉字、数字、短划线（-），长度限制为 2～64 个字符。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="nodeConfig")
    def node_config(self) -> pulumi.Output['outputs.NodePoolNodeConfig']:
        """
        节点池中云服务器（ECS）实例配置。
        """
        return pulumi.get(self, "node_config")

    @property
    @pulumi.getter(name="nodePoolId")
    def node_pool_id(self) -> pulumi.Output[builtins.str]:
        """
        节点池 ID 。
        """
        return pulumi.get(self, "node_pool_id")

    @property
    @pulumi.getter(name="nodeStatistics")
    def node_statistics(self) -> pulumi.Output['outputs.NodePoolNodeStatistics']:
        """
        节点池中的节点统计。
        """
        return pulumi.get(self, "node_statistics")

    @property
    @pulumi.getter(name="retainResources")
    def retain_resources(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        删除节点池时，指定保留的相关资源，取值：取值为空：（默认值）删除关联资源。Ecs：删除节点池时，保留节点池中的云服务器（ECS）实例。若指定的节点池内存在包年包月的云服务器实例，且未选择保留云服务器，则该接口仅从节点池中移除云服务器实例，不会删除。您可以通过云服务器控制台或云服务器API查询到该实例，并按需执行后续操作。
        """
        return pulumi.get(self, "retain_resources")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output['outputs.NodePoolStatus']:
        """
        节点池状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.NodePoolTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        更新节点池的时间。
        """
        return pulumi.get(self, "updated_time")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetKafkaTriggerResult',
    'AwaitableGetKafkaTriggerResult',
    'get_kafka_trigger',
    'get_kafka_trigger_output',
]

@pulumi.output_type
class GetKafkaTriggerResult:
    """
    A collection of values returned by getKafkaTrigger.
    """
    def __init__(__self__, batch_flush_duration_milliseconds=None, batch_size=None, consumer_group=None, created_time=None, description=None, enabled=None, function_id=None, id=None, kafka_credentials=None, kafka_trigger_id=None, maximum_retry_attempts=None, mq_instance_id=None, name=None, starting_position=None, status=None, topic_name=None, updated_time=None):
        if batch_flush_duration_milliseconds and not isinstance(batch_flush_duration_milliseconds, int):
            raise TypeError("Expected argument 'batch_flush_duration_milliseconds' to be a int")
        pulumi.set(__self__, "batch_flush_duration_milliseconds", batch_flush_duration_milliseconds)
        if batch_size and not isinstance(batch_size, int):
            raise TypeError("Expected argument 'batch_size' to be a int")
        pulumi.set(__self__, "batch_size", batch_size)
        if consumer_group and not isinstance(consumer_group, str):
            raise TypeError("Expected argument 'consumer_group' to be a str")
        pulumi.set(__self__, "consumer_group", consumer_group)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if enabled and not isinstance(enabled, bool):
            raise TypeError("Expected argument 'enabled' to be a bool")
        pulumi.set(__self__, "enabled", enabled)
        if function_id and not isinstance(function_id, str):
            raise TypeError("Expected argument 'function_id' to be a str")
        pulumi.set(__self__, "function_id", function_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if kafka_credentials and not isinstance(kafka_credentials, dict):
            raise TypeError("Expected argument 'kafka_credentials' to be a dict")
        pulumi.set(__self__, "kafka_credentials", kafka_credentials)
        if kafka_trigger_id and not isinstance(kafka_trigger_id, str):
            raise TypeError("Expected argument 'kafka_trigger_id' to be a str")
        pulumi.set(__self__, "kafka_trigger_id", kafka_trigger_id)
        if maximum_retry_attempts and not isinstance(maximum_retry_attempts, int):
            raise TypeError("Expected argument 'maximum_retry_attempts' to be a int")
        pulumi.set(__self__, "maximum_retry_attempts", maximum_retry_attempts)
        if mq_instance_id and not isinstance(mq_instance_id, str):
            raise TypeError("Expected argument 'mq_instance_id' to be a str")
        pulumi.set(__self__, "mq_instance_id", mq_instance_id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if starting_position and not isinstance(starting_position, str):
            raise TypeError("Expected argument 'starting_position' to be a str")
        pulumi.set(__self__, "starting_position", starting_position)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if topic_name and not isinstance(topic_name, str):
            raise TypeError("Expected argument 'topic_name' to be a str")
        pulumi.set(__self__, "topic_name", topic_name)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="batchFlushDurationMilliseconds")
    def batch_flush_duration_milliseconds(self) -> builtins.int:
        """
        触发器批量消费的最长等待时间。单位为毫秒（ms），取值范围为 1000 ~ 60000 ms，默认值为 1000 ms。
        """
        return pulumi.get(self, "batch_flush_duration_milliseconds")

    @property
    @pulumi.getter(name="batchSize")
    def batch_size(self) -> builtins.int:
        """
        触发器批量消费的每批次消息数。
        """
        return pulumi.get(self, "batch_size")

    @property
    @pulumi.getter(name="consumerGroup")
    def consumer_group(self) -> builtins.str:
        """
        消息队列 Kafka 实例的消费组名字。
        """
        return pulumi.get(self, "consumer_group")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        Kafka 触发器创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Kafka 触发器描述。长度限制为 200 个字符以内。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def enabled(self) -> builtins.bool:
        """
        是否在创建触发器的同时启用触发器。取值：true：启用。false：关闭。
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter(name="functionId")
    def function_id(self) -> builtins.str:
        """
        函数 ID。
        """
        return pulumi.get(self, "function_id")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="kafkaCredentials")
    def kafka_credentials(self) -> 'outputs.GetKafkaTriggerKafkaCredentialsResult':
        """
        Kafka 身份认证。函数服务将通过 Kafka ACL 权限策略，对 PLAIN 和 SCRAM-SHA-256 两种类型的 SASL 用户进行消息消费鉴权。
        """
        return pulumi.get(self, "kafka_credentials")

    @property
    @pulumi.getter(name="kafkaTriggerId")
    def kafka_trigger_id(self) -> builtins.str:
        """
        Kafka 触发器 ID。
        """
        return pulumi.get(self, "kafka_trigger_id")

    @property
    @pulumi.getter(name="maximumRetryAttempts")
    def maximum_retry_attempts(self) -> builtins.int:
        """
        函数发生运行错误（包括用户代码错误和 Runtime 错误）时的最大重试次数。取值范围为 0～100 的正整数。
        """
        return pulumi.get(self, "maximum_retry_attempts")

    @property
    @pulumi.getter(name="mqInstanceId")
    def mq_instance_id(self) -> builtins.str:
        """
        消息队列 Kafka 实例 ID。
        """
        return pulumi.get(self, "mq_instance_id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Kafka 触发器名字。同一函数下，触发器名称不可重复。只能包含大小写字母、数字、下划线，并且以字母开头，长度限制为 4~63 个字符。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="startingPosition")
    def starting_position(self) -> builtins.str:
        """
        指定开始消费 Topic 中消息的位置。取值：Latest：只消费订阅 Topic 后产生的消息。Earliest：从 Topic 中生产的第一条消息开始消费。
        """
        return pulumi.get(self, "starting_position")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        Kafka 触发器状态。参数值说明：ready：运行，failed：失败，pending：启动中
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="topicName")
    def topic_name(self) -> builtins.str:
        """
        消息队列 Kafka 实例的 Topic 名称。
        """
        return pulumi.get(self, "topic_name")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        Kafka 触发器最近一次更新时间。
        """
        return pulumi.get(self, "updated_time")


class AwaitableGetKafkaTriggerResult(GetKafkaTriggerResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetKafkaTriggerResult(
            batch_flush_duration_milliseconds=self.batch_flush_duration_milliseconds,
            batch_size=self.batch_size,
            consumer_group=self.consumer_group,
            created_time=self.created_time,
            description=self.description,
            enabled=self.enabled,
            function_id=self.function_id,
            id=self.id,
            kafka_credentials=self.kafka_credentials,
            kafka_trigger_id=self.kafka_trigger_id,
            maximum_retry_attempts=self.maximum_retry_attempts,
            mq_instance_id=self.mq_instance_id,
            name=self.name,
            starting_position=self.starting_position,
            status=self.status,
            topic_name=self.topic_name,
            updated_time=self.updated_time)


def get_kafka_trigger(id: Optional[builtins.str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetKafkaTriggerResult:
    """
    Data Source schema for Byteplus::VEFAAS::KafkaTrigger


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:vefaas/getKafkaTrigger:getKafkaTrigger', __args__, opts=opts, typ=GetKafkaTriggerResult).value

    return AwaitableGetKafkaTriggerResult(
        batch_flush_duration_milliseconds=pulumi.get(__ret__, 'batch_flush_duration_milliseconds'),
        batch_size=pulumi.get(__ret__, 'batch_size'),
        consumer_group=pulumi.get(__ret__, 'consumer_group'),
        created_time=pulumi.get(__ret__, 'created_time'),
        description=pulumi.get(__ret__, 'description'),
        enabled=pulumi.get(__ret__, 'enabled'),
        function_id=pulumi.get(__ret__, 'function_id'),
        id=pulumi.get(__ret__, 'id'),
        kafka_credentials=pulumi.get(__ret__, 'kafka_credentials'),
        kafka_trigger_id=pulumi.get(__ret__, 'kafka_trigger_id'),
        maximum_retry_attempts=pulumi.get(__ret__, 'maximum_retry_attempts'),
        mq_instance_id=pulumi.get(__ret__, 'mq_instance_id'),
        name=pulumi.get(__ret__, 'name'),
        starting_position=pulumi.get(__ret__, 'starting_position'),
        status=pulumi.get(__ret__, 'status'),
        topic_name=pulumi.get(__ret__, 'topic_name'),
        updated_time=pulumi.get(__ret__, 'updated_time'))
def get_kafka_trigger_output(id: Optional[pulumi.Input[builtins.str]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetKafkaTriggerResult]:
    """
    Data Source schema for Byteplus::VEFAAS::KafkaTrigger


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:vefaas/getKafkaTrigger:getKafkaTrigger', __args__, opts=opts, typ=GetKafkaTriggerResult)
    return __ret__.apply(lambda __response__: GetKafkaTriggerResult(
        batch_flush_duration_milliseconds=pulumi.get(__response__, 'batch_flush_duration_milliseconds'),
        batch_size=pulumi.get(__response__, 'batch_size'),
        consumer_group=pulumi.get(__response__, 'consumer_group'),
        created_time=pulumi.get(__response__, 'created_time'),
        description=pulumi.get(__response__, 'description'),
        enabled=pulumi.get(__response__, 'enabled'),
        function_id=pulumi.get(__response__, 'function_id'),
        id=pulumi.get(__response__, 'id'),
        kafka_credentials=pulumi.get(__response__, 'kafka_credentials'),
        kafka_trigger_id=pulumi.get(__response__, 'kafka_trigger_id'),
        maximum_retry_attempts=pulumi.get(__response__, 'maximum_retry_attempts'),
        mq_instance_id=pulumi.get(__response__, 'mq_instance_id'),
        name=pulumi.get(__response__, 'name'),
        starting_position=pulumi.get(__response__, 'starting_position'),
        status=pulumi.get(__response__, 'status'),
        topic_name=pulumi.get(__response__, 'topic_name'),
        updated_time=pulumi.get(__response__, 'updated_time')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetSnatentryResult',
    'AwaitableGetSnatentryResult',
    'get_snatentry',
    'get_snatentry_output',
]

@pulumi.output_type
class GetSnatentryResult:
    """
    A collection of values returned by getSnatentry.
    """
    def __init__(__self__, eip_address=None, eip_id=None, id=None, nat_gateway_id=None, nat_ip_id=None, snat_entry_id=None, snat_entry_name=None, source_cidr=None, status=None, subnet_id=None):
        if eip_address and not isinstance(eip_address, str):
            raise TypeError("Expected argument 'eip_address' to be a str")
        pulumi.set(__self__, "eip_address", eip_address)
        if eip_id and not isinstance(eip_id, str):
            raise TypeError("Expected argument 'eip_id' to be a str")
        pulumi.set(__self__, "eip_id", eip_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if nat_gateway_id and not isinstance(nat_gateway_id, str):
            raise TypeError("Expected argument 'nat_gateway_id' to be a str")
        pulumi.set(__self__, "nat_gateway_id", nat_gateway_id)
        if nat_ip_id and not isinstance(nat_ip_id, str):
            raise TypeError("Expected argument 'nat_ip_id' to be a str")
        pulumi.set(__self__, "nat_ip_id", nat_ip_id)
        if snat_entry_id and not isinstance(snat_entry_id, str):
            raise TypeError("Expected argument 'snat_entry_id' to be a str")
        pulumi.set(__self__, "snat_entry_id", snat_entry_id)
        if snat_entry_name and not isinstance(snat_entry_name, str):
            raise TypeError("Expected argument 'snat_entry_name' to be a str")
        pulumi.set(__self__, "snat_entry_name", snat_entry_name)
        if source_cidr and not isinstance(source_cidr, str):
            raise TypeError("Expected argument 'source_cidr' to be a str")
        pulumi.set(__self__, "source_cidr", source_cidr)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if subnet_id and not isinstance(subnet_id, str):
            raise TypeError("Expected argument 'subnet_id' to be a str")
        pulumi.set(__self__, "subnet_id", subnet_id)

    @property
    @pulumi.getter(name="eipAddress")
    def eip_address(self) -> builtins.str:
        """
        SNAT规则关联的公网IP的IP地址。返回单个公网IP的IP地址。 返回多个公网IP的IP地址。
        """
        return pulumi.get(self, "eip_address")

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> builtins.str:
        """
        SNAT规则关联的公网IP的ID。返回单个公网IP的ID。 返回多个公网IP的ID。
        """
        return pulumi.get(self, "eip_id")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> builtins.str:
        """
        SNAT规则所属NAT网关的ID。
        """
        return pulumi.get(self, "nat_gateway_id")

    @property
    @pulumi.getter(name="natIpId")
    def nat_ip_id(self) -> builtins.str:
        """
        私网NAT网关的中转IP的ID。
        """
        return pulumi.get(self, "nat_ip_id")

    @property
    @pulumi.getter(name="snatEntryId")
    def snat_entry_id(self) -> builtins.str:
        """
        SNAT规则的ID。
        """
        return pulumi.get(self, "snat_entry_id")

    @property
    @pulumi.getter(name="snatEntryName")
    def snat_entry_name(self) -> builtins.str:
        """
        SNAT规则的名称。
        """
        return pulumi.get(self, "snat_entry_name")

    @property
    @pulumi.getter(name="sourceCidr")
    def source_cidr(self) -> builtins.str:
        """
        SNAT规则对应的网段。
        """
        return pulumi.get(self, "source_cidr")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        SNAT规则的状态。Creating：创建中。Deleting：删除中。Available：可用。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> builtins.str:
        """
        SNAT规则关联子网的ID。
        """
        return pulumi.get(self, "subnet_id")


class AwaitableGetSnatentryResult(GetSnatentryResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSnatentryResult(
            eip_address=self.eip_address,
            eip_id=self.eip_id,
            id=self.id,
            nat_gateway_id=self.nat_gateway_id,
            nat_ip_id=self.nat_ip_id,
            snat_entry_id=self.snat_entry_id,
            snat_entry_name=self.snat_entry_name,
            source_cidr=self.source_cidr,
            status=self.status,
            subnet_id=self.subnet_id)


def get_snatentry(id: Optional[builtins.str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSnatentryResult:
    """
    Data Source schema for Byteplus::NatGateway::Snatentry


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:natgateway/getSnatentry:getSnatentry', __args__, opts=opts, typ=GetSnatentryResult).value

    return AwaitableGetSnatentryResult(
        eip_address=pulumi.get(__ret__, 'eip_address'),
        eip_id=pulumi.get(__ret__, 'eip_id'),
        id=pulumi.get(__ret__, 'id'),
        nat_gateway_id=pulumi.get(__ret__, 'nat_gateway_id'),
        nat_ip_id=pulumi.get(__ret__, 'nat_ip_id'),
        snat_entry_id=pulumi.get(__ret__, 'snat_entry_id'),
        snat_entry_name=pulumi.get(__ret__, 'snat_entry_name'),
        source_cidr=pulumi.get(__ret__, 'source_cidr'),
        status=pulumi.get(__ret__, 'status'),
        subnet_id=pulumi.get(__ret__, 'subnet_id'))
def get_snatentry_output(id: Optional[pulumi.Input[builtins.str]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSnatentryResult]:
    """
    Data Source schema for Byteplus::NatGateway::Snatentry


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:natgateway/getSnatentry:getSnatentry', __args__, opts=opts, typ=GetSnatentryResult)
    return __ret__.apply(lambda __response__: GetSnatentryResult(
        eip_address=pulumi.get(__response__, 'eip_address'),
        eip_id=pulumi.get(__response__, 'eip_id'),
        id=pulumi.get(__response__, 'id'),
        nat_gateway_id=pulumi.get(__response__, 'nat_gateway_id'),
        nat_ip_id=pulumi.get(__response__, 'nat_ip_id'),
        snat_entry_id=pulumi.get(__response__, 'snat_entry_id'),
        snat_entry_name=pulumi.get(__response__, 'snat_entry_name'),
        source_cidr=pulumi.get(__response__, 'source_cidr'),
        status=pulumi.get(__response__, 'status'),
        subnet_id=pulumi.get(__response__, 'subnet_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetUserResult',
    'AwaitableGetUserResult',
    'get_user',
    'get_user_output',
]

@pulumi.output_type
class GetUserResult:
    """
    A collection of values returned by getUser.
    """
    def __init__(__self__, access_keys=None, account_id=None, create_date=None, description=None, display_name=None, email=None, email_is_verify=None, groups=None, id=None, login_profile=None, mobile_phone=None, mobile_phone_is_verify=None, policies=None, security_config=None, tags=None, trn=None, update_date=None, user_id=None, user_name=None):
        if access_keys and not isinstance(access_keys, list):
            raise TypeError("Expected argument 'access_keys' to be a list")
        pulumi.set(__self__, "access_keys", access_keys)
        if account_id and not isinstance(account_id, float):
            raise TypeError("Expected argument 'account_id' to be a float")
        pulumi.set(__self__, "account_id", account_id)
        if create_date and not isinstance(create_date, str):
            raise TypeError("Expected argument 'create_date' to be a str")
        pulumi.set(__self__, "create_date", create_date)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if email and not isinstance(email, str):
            raise TypeError("Expected argument 'email' to be a str")
        pulumi.set(__self__, "email", email)
        if email_is_verify and not isinstance(email_is_verify, bool):
            raise TypeError("Expected argument 'email_is_verify' to be a bool")
        pulumi.set(__self__, "email_is_verify", email_is_verify)
        if groups and not isinstance(groups, list):
            raise TypeError("Expected argument 'groups' to be a list")
        pulumi.set(__self__, "groups", groups)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if login_profile and not isinstance(login_profile, dict):
            raise TypeError("Expected argument 'login_profile' to be a dict")
        pulumi.set(__self__, "login_profile", login_profile)
        if mobile_phone and not isinstance(mobile_phone, str):
            raise TypeError("Expected argument 'mobile_phone' to be a str")
        pulumi.set(__self__, "mobile_phone", mobile_phone)
        if mobile_phone_is_verify and not isinstance(mobile_phone_is_verify, bool):
            raise TypeError("Expected argument 'mobile_phone_is_verify' to be a bool")
        pulumi.set(__self__, "mobile_phone_is_verify", mobile_phone_is_verify)
        if policies and not isinstance(policies, list):
            raise TypeError("Expected argument 'policies' to be a list")
        pulumi.set(__self__, "policies", policies)
        if security_config and not isinstance(security_config, dict):
            raise TypeError("Expected argument 'security_config' to be a dict")
        pulumi.set(__self__, "security_config", security_config)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if trn and not isinstance(trn, str):
            raise TypeError("Expected argument 'trn' to be a str")
        pulumi.set(__self__, "trn", trn)
        if update_date and not isinstance(update_date, str):
            raise TypeError("Expected argument 'update_date' to be a str")
        pulumi.set(__self__, "update_date", update_date)
        if user_id and not isinstance(user_id, int):
            raise TypeError("Expected argument 'user_id' to be a int")
        pulumi.set(__self__, "user_id", user_id)
        if user_name and not isinstance(user_name, str):
            raise TypeError("Expected argument 'user_name' to be a str")
        pulumi.set(__self__, "user_name", user_name)

    @property
    @pulumi.getter(name="accessKeys")
    def access_keys(self) -> Sequence['outputs.GetUserAccessKeyResult']:
        """
        子用户的访问密钥。
        """
        return pulumi.get(self, "access_keys")

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> builtins.float:
        """
        子用户归属的主账号。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="createDate")
    def create_date(self) -> builtins.str:
        """
        子用户对应的创建时间。
        """
        return pulumi.get(self, "create_date")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        子用户对应的描述信息，长度不超过255。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> builtins.str:
        """
        子用户对应的展示名称，用户显示名。长度1~128，仅支持中文、英文、数字、空格和.-_@符号。
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def email(self) -> builtins.str:
        """
        子用户对应的电子邮件地址。
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter(name="emailIsVerify")
    def email_is_verify(self) -> builtins.bool:
        """
        子用户电子邮件地址是否已验证。true代表已验证，false代表未验证。
        """
        return pulumi.get(self, "email_is_verify")

    @property
    @pulumi.getter
    def groups(self) -> Sequence[builtins.str]:
        """
        子用户归属的用户组。
        """
        return pulumi.get(self, "groups")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="loginProfile")
    def login_profile(self) -> 'outputs.GetUserLoginProfileResult':
        """
        子用户的登录配置。
        """
        return pulumi.get(self, "login_profile")

    @property
    @pulumi.getter(name="mobilePhone")
    def mobile_phone(self) -> builtins.str:
        """
        子用户对应的手机号。
        """
        return pulumi.get(self, "mobile_phone")

    @property
    @pulumi.getter(name="mobilePhoneIsVerify")
    def mobile_phone_is_verify(self) -> builtins.bool:
        """
        子用户手机号是否已验证。true代表已验证，false代表未验证。
        """
        return pulumi.get(self, "mobile_phone_is_verify")

    @property
    @pulumi.getter
    def policies(self) -> Sequence['outputs.GetUserPolicyResult']:
        """
        子用户对应的权限策略。
        """
        return pulumi.get(self, "policies")

    @property
    @pulumi.getter(name="securityConfig")
    def security_config(self) -> 'outputs.GetUserSecurityConfigResult':
        """
        子用户的操作保护配置。
        """
        return pulumi.get(self, "security_config")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetUserTagResult']:
        """
        子用户对应的资源标签。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def trn(self) -> builtins.str:
        """
        子用户对应的Trn表达式。
        """
        return pulumi.get(self, "trn")

    @property
    @pulumi.getter(name="updateDate")
    def update_date(self) -> builtins.str:
        """
        子用户对应的更新时间。
        """
        return pulumi.get(self, "update_date")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> builtins.int:
        """
        子用户的ID。
        """
        return pulumi.get(self, "user_id")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> builtins.str:
        """
        子用户名称，用户名。长度1~64，支持英文、数字、下划线、和.-@符号。
        """
        return pulumi.get(self, "user_name")


class AwaitableGetUserResult(GetUserResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUserResult(
            access_keys=self.access_keys,
            account_id=self.account_id,
            create_date=self.create_date,
            description=self.description,
            display_name=self.display_name,
            email=self.email,
            email_is_verify=self.email_is_verify,
            groups=self.groups,
            id=self.id,
            login_profile=self.login_profile,
            mobile_phone=self.mobile_phone,
            mobile_phone_is_verify=self.mobile_phone_is_verify,
            policies=self.policies,
            security_config=self.security_config,
            tags=self.tags,
            trn=self.trn,
            update_date=self.update_date,
            user_id=self.user_id,
            user_name=self.user_name)


def get_user(id: Optional[builtins.str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUserResult:
    """
    Data Source schema for Byteplus::IAM::User


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:iam/getUser:getUser', __args__, opts=opts, typ=GetUserResult).value

    return AwaitableGetUserResult(
        access_keys=pulumi.get(__ret__, 'access_keys'),
        account_id=pulumi.get(__ret__, 'account_id'),
        create_date=pulumi.get(__ret__, 'create_date'),
        description=pulumi.get(__ret__, 'description'),
        display_name=pulumi.get(__ret__, 'display_name'),
        email=pulumi.get(__ret__, 'email'),
        email_is_verify=pulumi.get(__ret__, 'email_is_verify'),
        groups=pulumi.get(__ret__, 'groups'),
        id=pulumi.get(__ret__, 'id'),
        login_profile=pulumi.get(__ret__, 'login_profile'),
        mobile_phone=pulumi.get(__ret__, 'mobile_phone'),
        mobile_phone_is_verify=pulumi.get(__ret__, 'mobile_phone_is_verify'),
        policies=pulumi.get(__ret__, 'policies'),
        security_config=pulumi.get(__ret__, 'security_config'),
        tags=pulumi.get(__ret__, 'tags'),
        trn=pulumi.get(__ret__, 'trn'),
        update_date=pulumi.get(__ret__, 'update_date'),
        user_id=pulumi.get(__ret__, 'user_id'),
        user_name=pulumi.get(__ret__, 'user_name'))
def get_user_output(id: Optional[pulumi.Input[builtins.str]] = None,
                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetUserResult]:
    """
    Data Source schema for Byteplus::IAM::User


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:iam/getUser:getUser', __args__, opts=opts, typ=GetUserResult)
    return __ret__.apply(lambda __response__: GetUserResult(
        access_keys=pulumi.get(__response__, 'access_keys'),
        account_id=pulumi.get(__response__, 'account_id'),
        create_date=pulumi.get(__response__, 'create_date'),
        description=pulumi.get(__response__, 'description'),
        display_name=pulumi.get(__response__, 'display_name'),
        email=pulumi.get(__response__, 'email'),
        email_is_verify=pulumi.get(__response__, 'email_is_verify'),
        groups=pulumi.get(__response__, 'groups'),
        id=pulumi.get(__response__, 'id'),
        login_profile=pulumi.get(__response__, 'login_profile'),
        mobile_phone=pulumi.get(__response__, 'mobile_phone'),
        mobile_phone_is_verify=pulumi.get(__response__, 'mobile_phone_is_verify'),
        policies=pulumi.get(__response__, 'policies'),
        security_config=pulumi.get(__response__, 'security_config'),
        tags=pulumi.get(__response__, 'tags'),
        trn=pulumi.get(__response__, 'trn'),
        update_date=pulumi.get(__response__, 'update_date'),
        user_id=pulumi.get(__response__, 'user_id'),
        user_name=pulumi.get(__response__, 'user_name')))
